# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'toolkit_ui.ui'
##
## Created by: Qt User Interface Compiler version 5.15.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import (QCoreApplication, QDate, QDateTime, QMetaObject,
    QObject, QPoint, QRect, QSize, QTime, QUrl, Qt)
from PySide2.QtGui import (QBrush, QColor, QConicalGradient, QCursor, QFont,
    QFontDatabase, QIcon, QKeySequence, QLinearGradient, QPalette, QPainter,
    QPixmap, QRadialGradient)
from PySide2.QtWidgets import *

from  . import rsrc_rc

class Ui_ToolbarPanel(object):
    def setupUi(self, ToolbarPanel):
        if not ToolbarPanel.objectName():
            ToolbarPanel.setObjectName(u"ToolbarPanel")
        ToolbarPanel.resize(30, 600)
        sizePolicy = QSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(ToolbarPanel.sizePolicy().hasHeightForWidth())
        ToolbarPanel.setSizePolicy(sizePolicy)
        ToolbarPanel.setMinimumSize(QSize(30, 337))
        ToolbarPanel.setMaximumSize(QSize(30, 600))
        ToolbarPanel.setBaseSize(QSize(30, 403))
        ToolbarPanel.setWindowTitle(u"guiscrcpy")
        icon = QIcon()
        icon.addFile(u":/res/ui/guiscrcpy_logo.png", QSize(), QIcon.Normal, QIcon.Off)
        ToolbarPanel.setWindowIcon(icon)
        ToolbarPanel.setWindowOpacity(1.000000000000000)
        ToolbarPanel.setStyleSheet(u"QDialog{\n"
"width: 30px\n"
"}\n"
"QPushButton {\n"
"                        \n"
"\n"
"border-radius: 1px;\n"
"		background-color: qlineargradient(spread:pad, x1:0, y1:0.915182, x2:0, y2:0.926, stop:0.897059 rgba(41, 41, 41, 255), stop:1 rgba(30, 30, 30, 255));\n"
"color: rgb(0, 0, 0);\n"
"                        \n"
"                    }\n"
"\n"
"QPushButton:pressed {\n"
"border-radius: 5px;\n"
"					  \n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 152, 255));\n"
"color: rgb(0, 0, 0);\n"
"                        }\n"
"QPushButton:hover {\n"
"border-radius: 5px;\n"
"					  \n"
"	background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 199, 199, 255), stop:1 rgba(0, 190, 113, 255));\n"
"color: rgb(0, 0, 0);\n"
"                        }\n"
"")
        self.layoutWidget = QWidget(ToolbarPanel)
        self.layoutWidget.setObjectName(u"layoutWidget")
        self.layoutWidget.setGeometry(QRect(0, 0, 33, 601))
        self.verticalLayout = QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setMargin(0)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setSizeConstraint(QLayout.SetMaximumSize)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.screenfreeze = QPushButton(self.layoutWidget)
        self.screenfreeze.setObjectName(u"screenfreeze")
        self.screenfreeze.setEnabled(True)
        sizePolicy1 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.screenfreeze.sizePolicy().hasHeightForWidth())
        self.screenfreeze.setSizePolicy(sizePolicy1)
        self.screenfreeze.setMouseTracking(True)
        self.screenfreeze.setTabletTracking(True)
        self.screenfreeze.setAutoFillBackground(False)
        self.screenfreeze.setStyleSheet(u"")
        icon1 = QIcon()
        icon1.addFile(u":/icons/icons/cross-mark-on-a-black-circle-background.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.screenfreeze.setIcon(icon1)
        self.screenfreeze.setFlat(True)

        self.verticalLayout.addWidget(self.screenfreeze)

        self.fullscreenUI = QPushButton(self.layoutWidget)
        self.fullscreenUI.setObjectName(u"fullscreenUI")
        self.fullscreenUI.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.fullscreenUI.sizePolicy().hasHeightForWidth())
        self.fullscreenUI.setSizePolicy(sizePolicy1)
        self.fullscreenUI.setMouseTracking(True)
        self.fullscreenUI.setTabletTracking(True)
        self.fullscreenUI.setAutoFillBackground(False)
        self.fullscreenUI.setStyleSheet(u"")
        icon2 = QIcon()
        icon2.addFile(u":/icons/icons/increase-size-option.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.fullscreenUI.setIcon(icon2)
        self.fullscreenUI.setFlat(True)

        self.verticalLayout.addWidget(self.fullscreenUI)

        self.notif_pull = QPushButton(self.layoutWidget)
        self.notif_pull.setObjectName(u"notif_pull")
        self.notif_pull.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.notif_pull.sizePolicy().hasHeightForWidth())
        self.notif_pull.setSizePolicy(sizePolicy1)
        self.notif_pull.setMouseTracking(True)
        self.notif_pull.setTabletTracking(True)
        self.notif_pull.setAutoFillBackground(False)
        self.notif_pull.setStyleSheet(u"")
        icon3 = QIcon()
        icon3.addFile(u":/icons/icons/bell-musical-tool.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.notif_pull.setIcon(icon3)
        self.notif_pull.setFlat(True)

        self.verticalLayout.addWidget(self.notif_pull)

        self.notif_collapse = QPushButton(self.layoutWidget)
        self.notif_collapse.setObjectName(u"notif_collapse")
        self.notif_collapse.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.notif_collapse.sizePolicy().hasHeightForWidth())
        self.notif_collapse.setSizePolicy(sizePolicy1)
        self.notif_collapse.setMouseTracking(True)
        self.notif_collapse.setTabletTracking(True)
        self.notif_collapse.setAutoFillBackground(False)
        self.notif_collapse.setStyleSheet(u"")
        icon4 = QIcon()
        icon4.addFile(u":/icons/icons/bell-musical-tool(2).svg", QSize(), QIcon.Normal, QIcon.Off)
        self.notif_collapse.setIcon(icon4)
        self.notif_collapse.setFlat(True)

        self.verticalLayout.addWidget(self.notif_collapse)

        self.clipD2PC = QPushButton(self.layoutWidget)
        self.clipD2PC.setObjectName(u"clipD2PC")
        self.clipD2PC.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.clipD2PC.sizePolicy().hasHeightForWidth())
        self.clipD2PC.setSizePolicy(sizePolicy1)
        self.clipD2PC.setMouseTracking(True)
        self.clipD2PC.setTabletTracking(True)
        self.clipD2PC.setAutoFillBackground(False)
        self.clipD2PC.setStyleSheet(u"")
        icon5 = QIcon()
        icon5.addFile(u":/icons/icons/copy-document.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.clipD2PC.setIcon(icon5)
        self.clipD2PC.setFlat(True)

        self.verticalLayout.addWidget(self.clipD2PC)

        self.clipPC2D = QPushButton(self.layoutWidget)
        self.clipPC2D.setObjectName(u"clipPC2D")
        self.clipPC2D.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.clipPC2D.sizePolicy().hasHeightForWidth())
        self.clipPC2D.setSizePolicy(sizePolicy1)
        self.clipPC2D.setMouseTracking(True)
        self.clipPC2D.setTabletTracking(True)
        self.clipPC2D.setAutoFillBackground(False)
        self.clipPC2D.setStyleSheet(u"")
        icon6 = QIcon()
        icon6.addFile(u":/icons/icons/copy-document(1).svg", QSize(), QIcon.Normal, QIcon.Off)
        self.clipPC2D.setIcon(icon6)
        self.clipPC2D.setFlat(True)

        self.verticalLayout.addWidget(self.clipPC2D)

        self.vup = QPushButton(self.layoutWidget)
        self.vup.setObjectName(u"vup")
        self.vup.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.vup.sizePolicy().hasHeightForWidth())
        self.vup.setSizePolicy(sizePolicy1)
        self.vup.setMouseTracking(True)
        self.vup.setTabletTracking(True)
        self.vup.setAutoFillBackground(False)
        self.vup.setStyleSheet(u"")
        icon7 = QIcon()
        icon7.addFile(u":/icons/icons/volume-up-interface-symbol.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.vup.setIcon(icon7)
        self.vup.setFlat(True)

        self.verticalLayout.addWidget(self.vup)

        self.vdown = QPushButton(self.layoutWidget)
        self.vdown.setObjectName(u"vdown")
        self.vdown.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.vdown.sizePolicy().hasHeightForWidth())
        self.vdown.setSizePolicy(sizePolicy1)
        self.vdown.setMouseTracking(True)
        self.vdown.setTabletTracking(True)
        self.vdown.setAutoFillBackground(False)
        self.vdown.setStyleSheet(u"")
        icon8 = QIcon()
        icon8.addFile(u":/icons/icons/reduced-volume.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.vdown.setIcon(icon8)
        self.vdown.setFlat(True)

        self.verticalLayout.addWidget(self.vdown)

        self.powerUI = QPushButton(self.layoutWidget)
        self.powerUI.setObjectName(u"powerUI")
        self.powerUI.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.powerUI.sizePolicy().hasHeightForWidth())
        self.powerUI.setSizePolicy(sizePolicy1)
        self.powerUI.setMouseTracking(True)
        self.powerUI.setTabletTracking(True)
        self.powerUI.setAutoFillBackground(False)
        self.powerUI.setStyleSheet(u"")
        icon9 = QIcon()
        icon9.addFile(u":/icons/icons/power.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.powerUI.setIcon(icon9)
        self.powerUI.setIconSize(QSize(16, 16))
        self.powerUI.setCheckable(False)
        self.powerUI.setFlat(True)

        self.verticalLayout.addWidget(self.powerUI)

        self.home = QPushButton(self.layoutWidget)
        self.home.setObjectName(u"home")
        self.home.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.home.sizePolicy().hasHeightForWidth())
        self.home.setSizePolicy(sizePolicy1)
        self.home.setMouseTracking(True)
        self.home.setTabletTracking(True)
        self.home.setAutoFillBackground(False)
        self.home.setStyleSheet(u"")
        icon10 = QIcon()
        icon10.addFile(u":/icons/icons/home.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.home.setIcon(icon10)
        self.home.setFlat(True)

        self.verticalLayout.addWidget(self.home)

        self.back = QPushButton(self.layoutWidget)
        self.back.setObjectName(u"back")
        self.back.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.back.sizePolicy().hasHeightForWidth())
        self.back.setSizePolicy(sizePolicy1)
        self.back.setMouseTracking(True)
        self.back.setTabletTracking(True)
        self.back.setAutoFillBackground(False)
        self.back.setStyleSheet(u"")
        icon11 = QIcon()
        icon11.addFile(u":/icons/icons/chevron-sign-left.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.back.setIcon(icon11)
        self.back.setFlat(True)

        self.verticalLayout.addWidget(self.back)

        self.menuUI = QPushButton(self.layoutWidget)
        self.menuUI.setObjectName(u"menuUI")
        self.menuUI.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.menuUI.sizePolicy().hasHeightForWidth())
        self.menuUI.setSizePolicy(sizePolicy1)
        self.menuUI.setMouseTracking(True)
        self.menuUI.setTabletTracking(True)
        self.menuUI.setAutoFillBackground(False)
        self.menuUI.setStyleSheet(u"")
        icon12 = QIcon()
        icon12.addFile(u":/icons/icons/reorder-option.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.menuUI.setIcon(icon12)
        self.menuUI.setFlat(True)

        self.verticalLayout.addWidget(self.menuUI)

        self.appswi = QPushButton(self.layoutWidget)
        self.appswi.setObjectName(u"appswi")
        self.appswi.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.appswi.sizePolicy().hasHeightForWidth())
        self.appswi.setSizePolicy(sizePolicy1)
        self.appswi.setMouseTracking(True)
        self.appswi.setTabletTracking(True)
        self.appswi.setAutoFillBackground(False)
        self.appswi.setStyleSheet(u"")
        icon13 = QIcon()
        icon13.addFile(u":/icons/icons/four-black-squares.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.appswi.setIcon(icon13)
        self.appswi.setFlat(True)

        self.verticalLayout.addWidget(self.appswi)

        self.pinchinUI = QPushButton(self.layoutWidget)
        self.pinchinUI.setObjectName(u"pinchinUI")
        self.pinchinUI.setEnabled(False)
        sizePolicy1.setHeightForWidth(self.pinchinUI.sizePolicy().hasHeightForWidth())
        self.pinchinUI.setSizePolicy(sizePolicy1)
        icon14 = QIcon()
        icon14.addFile(u":/icons/icons/zoom-in.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.pinchinUI.setIcon(icon14)
        self.pinchinUI.setFlat(True)

        self.verticalLayout.addWidget(self.pinchinUI)

        self.pinchoutUI = QPushButton(self.layoutWidget)
        self.pinchoutUI.setObjectName(u"pinchoutUI")
        self.pinchoutUI.setEnabled(False)
        sizePolicy1.setHeightForWidth(self.pinchoutUI.sizePolicy().hasHeightForWidth())
        self.pinchoutUI.setSizePolicy(sizePolicy1)
        icon15 = QIcon()
        icon15.addFile(u":/icons/icons/zoom-out.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.pinchoutUI.setIcon(icon15)
        self.pinchoutUI.setFlat(True)

        self.verticalLayout.addWidget(self.pinchoutUI)

        self.potraitUI = QPushButton(self.layoutWidget)
        self.potraitUI.setObjectName(u"potraitUI")
        self.potraitUI.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.potraitUI.sizePolicy().hasHeightForWidth())
        self.potraitUI.setSizePolicy(sizePolicy1)
        self.potraitUI.setToolTipDuration(2)
        icon16 = QIcon()
        icon16.addFile(u":/icons/icons/vertical-resizing-option.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.potraitUI.setIcon(icon16)
        self.potraitUI.setFlat(True)

        self.verticalLayout.addWidget(self.potraitUI)

        self.landscapeUI = QPushButton(self.layoutWidget)
        self.landscapeUI.setObjectName(u"landscapeUI")
        self.landscapeUI.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.landscapeUI.sizePolicy().hasHeightForWidth())
        self.landscapeUI.setSizePolicy(sizePolicy1)
        self.landscapeUI.setToolTipDuration(2)
        icon17 = QIcon()
        icon17.addFile(u":/icons/icons/horizontal-resize-option.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.landscapeUI.setIcon(icon17)
        self.landscapeUI.setFlat(True)

        self.verticalLayout.addWidget(self.landscapeUI)

        self.tk_device_id = QPushButton(self.layoutWidget)
        self.tk_device_id.setObjectName(u"tk_device_id")
        self.tk_device_id.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.tk_device_id.sizePolicy().hasHeightForWidth())
        self.tk_device_id.setSizePolicy(sizePolicy1)
        self.tk_device_id.setMinimumSize(QSize(0, 2))
        self.tk_device_id.setMaximumSize(QSize(16777215, 20))
        self.tk_device_id.setToolTipDuration(2)
        self.tk_device_id.setFlat(True)

        self.verticalLayout.addWidget(self.tk_device_id)

        self.label_2 = QLabel(self.layoutWidget)
        self.label_2.setObjectName(u"label_2")
        sizePolicy2 = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(0)
        sizePolicy2.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy2)
        font = QFont()
        font.setFamily(u"Noto Sans")
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setScaledContents(True)
        self.label_2.setAlignment(Qt.AlignCenter)

        self.verticalLayout.addWidget(self.label_2)

        self.label = QLabel(self.layoutWidget)
        self.label.setObjectName(u"label")
        sizePolicy2.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy2)
        self.label.setFont(font)
        self.label.setScaledContents(True)
        self.label.setAlignment(Qt.AlignCenter)

        self.verticalLayout.addWidget(self.label)


        self.retranslateUi(ToolbarPanel)

        QMetaObject.connectSlotsByName(ToolbarPanel)
    # setupUi

    def retranslateUi(self, ToolbarPanel):
        self.screenfreeze.setText("")
#if QT_CONFIG(tooltip)
        self.fullscreenUI.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Fullscreen", None))
#endif // QT_CONFIG(tooltip)
        self.fullscreenUI.setText("")
#if QT_CONFIG(tooltip)
        self.notif_pull.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Expand notification panel", None))
#endif // QT_CONFIG(tooltip)
        self.notif_pull.setText("")
#if QT_CONFIG(tooltip)
        self.notif_collapse.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Expand notification panel", None))
#endif // QT_CONFIG(tooltip)
        self.notif_collapse.setText("")
#if QT_CONFIG(tooltip)
        self.clipD2PC.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Copy device clipbioard to PC", None))
#endif // QT_CONFIG(tooltip)
        self.clipD2PC.setText("")
#if QT_CONFIG(tooltip)
        self.clipPC2D.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Copy PC clipboard to Device", None))
#endif // QT_CONFIG(tooltip)
        self.clipPC2D.setText("")
#if QT_CONFIG(tooltip)
        self.vup.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Volume Up", None))
#endif // QT_CONFIG(tooltip)
        self.vup.setText("")
        self.vdown.setText("")
#if QT_CONFIG(tooltip)
        self.powerUI.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Power on/off", None))
#endif // QT_CONFIG(tooltip)
        self.powerUI.setText("")
#if QT_CONFIG(tooltip)
        self.home.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Home key", None))
#endif // QT_CONFIG(tooltip)
        self.home.setText("")
#if QT_CONFIG(tooltip)
        self.back.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Back key", None))
#endif // QT_CONFIG(tooltip)
        self.back.setText("")
#if QT_CONFIG(tooltip)
        self.menuUI.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Menu key", None))
#endif // QT_CONFIG(tooltip)
        self.menuUI.setText("")
#if QT_CONFIG(tooltip)
        self.appswi.setToolTip(QCoreApplication.translate("ToolbarPanel", u"press the APP_SWITCH button", None))
#endif // QT_CONFIG(tooltip)
        self.appswi.setText("")
#if QT_CONFIG(tooltip)
        self.pinchinUI.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Pinch in the screen", None))
#endif // QT_CONFIG(tooltip)
        self.pinchinUI.setStyleSheet("")
        self.pinchinUI.setText("")
#if QT_CONFIG(tooltip)
        self.pinchoutUI.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Pinch out in the screen", None))
#endif // QT_CONFIG(tooltip)
        self.pinchoutUI.setStyleSheet("")
        self.pinchoutUI.setText("")
#if QT_CONFIG(tooltip)
        self.potraitUI.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Potrait", None))
#endif // QT_CONFIG(tooltip)
        self.potraitUI.setStyleSheet("")
        self.potraitUI.setText("")
#if QT_CONFIG(tooltip)
        self.landscapeUI.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Landscape", None))
#endif // QT_CONFIG(tooltip)
        self.landscapeUI.setStyleSheet("")
        self.landscapeUI.setText("")
#if QT_CONFIG(tooltip)
        self.tk_device_id.setToolTip(QCoreApplication.translate("ToolbarPanel", u"Landscape", None))
#endif // QT_CONFIG(tooltip)
        self.tk_device_id.setStyleSheet("")
        self.tk_device_id.setText("")
        self.label_2.setText(QCoreApplication.translate("ToolbarPanel", u"....", None))
        self.label.setText(QCoreApplication.translate("ToolbarPanel", u"::::", None))
        pass
    # retranslateUi




#!/usr/bin/env python3

"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.


Icon made by Dave Gandy from www.flaticon.com used under
Creative Commons 3.0 Unported. The original SVG black work
by Dave Gandy has been re-oriented, flipped or color-changed.
The rest of Terms and Conditions put forward by
CC-3.0:Unported has been feverently followed by the developer.
Icons have been adapted in all the three windows.

Icons pack obtained from www.flaticon.com
All rights reserved.

"""

import hashlib
import os
import subprocess
import sys
import time
import webbrowser
from subprocess import PIPE
from subprocess import Popen

from qtpy import QtCore, QtWidgets
from qtpy.QtCore import QModelIndex, QPoint
from qtpy.QtGui import QPixmap, QIcon, QFont, QFontDatabase
from qtpy.QtWidgets import QMainWindow, QListWidgetItem, QMenu
from qtpy.QtWidgets import QMessageBox

from .lib.bridge.audio.sndcpy import SndcpyBridge
from .lib.bridge.audio.usbaudio import USBAudioBridge
from .lib.config import InterfaceConfig
from .lib.utils import format_colors as fc
from .constants import FONTS
from .install.finder import open_exe_name_dialog
from .lib.process import is_running
from .lib.toolkit import UXMapper
from .lib.utils import log, get_self
from .platform import platform
from .theme.desktop_shortcut import desktop_device_shortcut_svg
from .theme.linux_desktop_shortcut_template import GUISCRCPY_DEVICE
from .theme.style import dark_stylesheet
from .ux import Ui_MainWindow
from .ux.panel import Panel
from .ux.swipe import SwipeUX
from .ux.toolkit import InterfaceToolkit
from .version import VERSION
from .lib.bridge import AndroidDebugBridge, ScrcpyBridge
from .lib.bridge.exceptions import ScrcpyServerNotFoundError


environment = platform.System()

# ============================================================================
# Load cairo-svg conditionally
if environment.system() == "Linux":
    try:
        from cairosvg import svg2png  # noqa:

        has_cairo = True
    except Exception as e:
        print("Failed to load cairo:", e)
        print("Some features are likely to be disabled")
        has_cairo = False


class InterfaceGuiscrcpy(QMainWindow, Ui_MainWindow):
    """
    Main class for guiscrcpy object.
    All the processes to spawn to scrcpy are handled here
    """

    # noinspection PyArgumentList
    def __init__(
        self,
        config_manager: InterfaceConfig,
        adb: AndroidDebugBridge,
        scrcpy: ScrcpyBridge,
        force_window_frame: bool = False,
        panels_not_always_on_top: bool = False,
        debug_no_scrcpy: bool = False,
    ):
        QMainWindow.__init__(self)
        Ui_MainWindow.__init__(self)
        self.setupUi(self)
        self._adb = adb
        self._scrcpy = scrcpy
        self.config_manager = config_manager
        config = self.config_manager.get_config()
        self._config = config
        self.panels_not_always_on_top = panels_not_always_on_top
        self.force_window_frame = force_window_frame
        self.debug__no_scrcpy = debug_no_scrcpy
        self.cmx = None
        self.sm = None
        self.mp = None
        self.nm = None
        self.swipe_instance = None
        self.panel_instance = None
        self.side_instance = None
        self.child_windows = list()
        self.options = ""
        log(
            "Options received by class are : {} {} {} {} {} ".format(
                config["bitrate"],
                config["dimension"],
                config["swtouches"],
                config["dispRO"],
                config["fullscreen"],
            )
        )
        # ====================================================================
        # Rotation; read config, update UI
        self.device_rotation.setCurrentIndex(config.get("rotation", 0))
        self.dial.setValue(int(config["bitrate"]))
        if config["swtouches"]:
            self.showTouches.setChecked(True)
        else:
            self.showTouches.setChecked(False)
        if config["dispRO"]:
            self.displayForceOn.setChecked(True)
        else:
            self.displayForceOn.setChecked(False)

        # panels
        if config["panels"].get("swipe"):
            self.check_swipe_panel.setChecked(True)
        else:
            self.check_swipe_panel.setChecked(False)
        if config["panels"].get("tookit"):
            self.check_side_panel.setChecked(True)
        else:
            self.check_side_panel.setChecked(False)
        if config["panels"].get("bottom"):
            self.check_bottom_panel.setChecked(True)
        else:
            self.check_bottom_panel.setChecked(False)

        # dimension
        if config["dimension"] is not None:
            self.dimensionDefaultCheckbox.setChecked(False)
            try:
                self.dimensionSlider.setValue(config["dimension"])
            except TypeError:
                self.dimensionDefaultCheckbox.setChecked(True)
        if config["fullscreen"]:
            self.fullscreen.setChecked(True)
        else:
            self.fullscreen.setChecked(False)
        if is_running("scrcpy"):
            log("SCRCPY RUNNING")
            self.display_public_message("SCRCPY SERVER RUNNING")
        else:
            log("SCRCPY SERVER IS INACTIVE")
            self.display_public_message("SCRCPY SERVER NOT RUNNING")

        # CONNECT DIMENSION CHECK BOX TO STATE CHANGE
        self.dimensionDefaultCheckbox.stateChanged.connect(self.__dimension_change_cb)
        self.build_label.setText("Build {} by srevinsaju".format(VERSION))

        # DIAL CTRL GRP
        self.dial.sliderMoved.connect(self.__dial_change_cb)
        self.dial.sliderReleased.connect(self.__dial_change_cb)
        # DIAL CTRL GRP

        # MAIN EXECUTE ACTION
        self.executeaction.clicked.connect(self.start_act)
        try:
            if config["extra"]:
                self.flaglineedit.setText(config["extra"])
        except Exception as err:
            log(f"Exception: flaglineedit.text(config[extra]) {err}")

        self.quit.clicked.connect(self.quit_window)
        self.dimensionText.setText("DEFAULT")
        config["bitrate"] = int(self.dial.value())
        self.bitrateText.setText(str(config["bitrate"]) + "KB/s")
        self.pushButton.setText("RESET")
        self.pushButton.clicked.connect(self.reset)
        self.abtgit.clicked.connect(self.launch_web_github)
        self.usbaud.clicked.connect(self.launch_usb_audio)
        self.initmapnow.clicked.connect(self.bootstrap_mapper)
        self.network_button.clicked.connect(self.network_mgr)
        self.settings_button.clicked.connect(self.settings_mgr)
        # self.devices_view.itemChanged.connect(self.update_rotation_combo_cb)
        self.devices_view.itemClicked.connect(self.update_rotation_combo_cb)
        self.refreshdevices.clicked.connect(self.scan_devices_update_list_view)
        self.restart_adb_server.clicked.connect(self.restart_adb_server_guiscrcpy)
        self.devices_view.itemClicked.connect(self.more_options_device_view)
        self.devices_view.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.scan_config_devices_update_list_view()
        self.refresh_devices()

    @property
    def adb(self) -> AndroidDebugBridge:
        return self._adb

    @property
    def scrcpy(self) -> ScrcpyBridge:
        return self._scrcpy

    @property
    def config(self) -> dict:
        return self._config

    def restart_adb_server_guiscrcpy(self):
        self.adb.kill_adb_server()

    def refresh_devices(self):
        """
        A slot for refreshing the QListView
        :return:
        """
        self.scan_devices_update_list_view()

    def update_rotation_combo_cb(self):
        """
        A proposed method for refreshing the rotation combobox on item
        change in the QListBox
        :return:
        """
        if self.devices_view.currentItem():
            _, device_id = self.current_device_identifier()
            _rotation = (
                self.config.get("device")
                .get(device_id, dict())
                .get("rotation", self.device_rotation.currentIndex())
            )
        else:
            _rotation = self.config.get("rotation", self.device_rotation.currentIndex())
        self.device_rotation.setCurrentIndex(_rotation)

    def settings_mgr(self):
        from guiscrcpy.ux.settings import InterfaceSettings

        self.sm = InterfaceSettings(self)
        self.sm.init()
        self.sm.show()

    def network_mgr(self):
        from guiscrcpy.ux.network import InterfaceNetwork

        self.nm = InterfaceNetwork(self.adb)
        self.nm.init()
        self.nm.show()

    def bootstrap_mapper(self):
        mapper_config_path = os.path.join(
            self.config_manager.get_cfgpath(), "guiscrcpy.mapper.json"
        )
        if os.path.exists(mapper_config_path):
            from guiscrcpy.lib.mapper.mapper import MapperAsync

            _, identifier = self.current_device_identifier()
            self.mp = MapperAsync(
                self,
                device_id=identifier,
                config_path=mapper_config_path,
                adb=self.adb,
                initialize=False,
            )
            self.mp.start()
            self.private_message_box_adb.setText("guiscrcpy-mapper has started")
        else:
            message_box = QMessageBox()
            message_box.setText(
                "guiscrcpy mapper is not initialized yet. Do you want to "
                "initialize it now?"
            )
            message_box.setInformativeText(
                "Before you initialize, make sure your phone is connected and "
                "the display is switched on to map the points."
            )
            message_box.setStandardButtons(QMessageBox.Yes | QMessageBox.No)
            user_message_box_response = message_box.exec()
            values_devices_list = self.scan_devices_update_list_view()
            self.check_devices_status_and_select_first_if_only_one(
                values_devices_list=values_devices_list
            )
            # TODO: allow enabling mapper from inside
            if user_message_box_response == QMessageBox.Yes:
                self.private_message_box_adb.setText("Initializing mapper...")
                print("Make sure your phone is connected and display is " "switched on")
                print(
                    "Reset mapper if you missed any "
                    "steps by 'guiscrcpy --mapper-reset'"
                )
                print()
                print(
                    "If at first you don't succeed... "
                    "reset, reset and reset again! :D"
                )
                print()
                _, identifier = self.current_device_identifier()
                executable = get_self()
                from .lib.utils import shellify as sx, open_process

                open_process(
                    sx("{} mapper".format(executable)),
                    stdout=sys.stdout,
                    stdin=sys.stdin,
                    stderr=sys.stderr,
                    cwd=os.getcwd(),
                )
                print("Mapper started")
                self.private_message_box_adb.setText("Mapper initialized")

    def launch_usb_audio(self):
        android_api_level = self.adb.get_target_android_version()

        if android_api_level == -1:
            return

        print("Detected device API level: " + str(android_api_level))

        if android_api_level >= 29:
            print("Using Sndcpy as audio bridge")
            audio_bridge = SndcpyBridge()
        else:
            print("Using USBAudio as audio bridge")
            audio_bridge = USBAudioBridge()

        # FIXME: provide the right device id
        audio_bridge.run(device_id=None)

    @staticmethod
    def launch_web_github():
        webbrowser.open("https://github.com/srevinsaju/guiscrcpy")

    def about(self):
        """
        Reset message box is based on aboutWindow object
        For some reason, I did not get time to fix that
        :return:
        """
        about_message_box = QMessageBox().window()
        about_message_box.about(
            self.pushButton,
            "Info",
            "Please restart guiscrcpy to reset the settings. "
            "guiscrcpy will now exit",
        )
        about_message_box.addButton("OK", about_message_box.hide)  # noqa:
        about_message_box.show()

    def reset(self):
        """
        Remove configuration files; Reset the mapper and guiscrcpy.json
        :return:
        """
        self.config_manager.reset_config()
        log("CONFIGURATION FILE REMOVED SUCCESSFULLY")
        log("RESTART")
        message_box = QMessageBox().window()
        message_box.about(
            self.pushButton,
            "Info",
            "Please restart guiscrcpy to reset the settings. "
            "guiscrcpy will now exit",
        )
        QMessageBox.ButtonRole()
        message_box.addButton("OK", self.quit_window)  # noqa:
        message_box.show()

    def quit_window(self):
        """
        A method to quit the main window
        :return:
        """
        try:
            self.mp.exit()
        except (AttributeError, KeyboardInterrupt):
            pass
        sys.exit()

    def forget_paired_device(self):
        """
        Forgets / Removes the configuration for saved
        :return: popped item / False
        """
        try:
            _, identifier = self.current_device_identifier()
            popped_device = self.config["device"].pop(identifier)
            self.refresh_devices()
            self.config_manager.update_config(self.config)
            self.config_manager.write_file()
            return popped_device
        except KeyError:
            return False

    def more_options_device_view(self, button):
        if "Disconnect" in button.text():
            menu = QMenu("Menu", self)
            menu.addAction("Pair / Ping", self.ping_paired_device)
            menu.addAction("Attempt TCPIP on device", self.tcpip_paired_device)
            menu.addAction("Forget device", self.forget_paired_device)
        else:
            menu = QMenu("Menu", self)
            menu.addAction("Attempt TCPIP on device", self.tcpip_paired_device)
            menu.addAction("Attempt reconnection", self.ping_paired_device)
            menu.addAction("Refresh", self.refresh_devices)
        _, identifier = self.current_device_identifier()
        if platform.System.system() == "Linux" and identifier.count(".") >= 3:
            menu.addAction(
                "Add Desktop Shortcut to this device",
                self.create_desktop_shortcut_linux_os,
            )
        menu.exec_(
            self.devices_view.mapToGlobal(
                QPoint(
                    self.devices_view.visualItemRect(button).x() + 22,
                    self.devices_view.visualItemRect(button).y() + 22,
                )
            )
        )

    def create_desktop_shortcut_linux_os(self) -> bool:
        """
        Creates a desktop shortcut for Linux OS
        :return: bool
        """
        # just a check before anything further happens because of an
        # unrelated OS
        if environment.system() != "Linux":
            log(
                "Tried to run create_desktop_shortcut_linux_os on an " "unsupported OS."
            )
            return False

        # get device specific configuration
        model, identifier = self.current_device_identifier()
        picture_file_path = self.config_manager.get_cfgpath()
        __sha_shift = self.config.get("sha_shift", 5)
        sha = hashlib.sha256(str(identifier).encode()).hexdigest()[
            __sha_shift : __sha_shift + 6
        ]
        log(f"Creating desktop shortcut sha: {sha}")
        path_to_image = os.path.join(picture_file_path, identifier + ".png")
        if has_cairo:
            svg2png(
                bytestring=desktop_device_shortcut_svg().format(f"#{sha}"),
                write_to=path_to_image,
            )
        else:
            print("Trying to use Plain SVG as renderer" " instead of cairo")
            with open(path_to_image, "w") as fp:
                svg_str = desktop_device_shortcut_svg().format(f"#{sha}")
                fp.write(svg_str)

        # go through all args; break when we find guiscrcpy
        for args_i in range(len(sys.argv)):
            if "guiscrcpy" in sys.argv[args_i]:
                aend = args_i + 1
                break
        else:
            aend = None

        sys_args_desktop = sys.argv[:aend]

        # check if its a python file
        # experimental support for AppImages / snaps
        # I am not sure; if it would work indeed
        for i in sys_args_desktop:
            if i.endswith(".py"):
                needs_python = True
                break
        else:
            needs_python = False
        if needs_python:
            sys_args_desktop = ["python3"] + sys_args_desktop

        # convert the list into a string
        sys_args_desktop = " ".join(sys_args_desktop)
        auto_connect_run_command = (
            "{executable} --connect={ip} "
            "--start --start-scrcpy-device-id={ip}".format(
                executable=sys_args_desktop, ip=identifier
            )
        )

        # create the desktop file using linux's desktop file gen method
        path_to_desktop_file = platform.System().create_desktop(
            desktop_file=GUISCRCPY_DEVICE.format(
                identifier=model,
                command=auto_connect_run_command,
                icon_path=path_to_image,
            ),
            desktop_file_name=f"{model}.guiscrcpy.desktop",
        )

        # announce it to developers / users
        log(f"Path to desktop file : {path_to_desktop_file}")
        print("Desktop file generated successfully")
        self.display_public_message("Desktop file has been created")
        return True

    def is_connection_success_handler(self, output: Popen, ip=None):
        out, err = output.communicate()
        if "failed" in out.decode() or "failed" in err.decode():
            self.display_public_message(
                "Failed to connect to {}. See the logs for more "
                "information".format(ip)
            )
            print("adb:", out.decode(), err.decode())
        else:
            self.display_public_message("Connection command completed successfully")

    def ping_paired_device(self, device_id=None):
        # update the configuration file first
        if not device_id:
            _, identifier = self.current_device_identifier()
            if identifier.count(".") == 3:
                wifi_device = True
            else:
                wifi_device = False
            try:
                self.config["device"][identifier]["wifi"] = wifi_device
            except KeyError:
                log(f"Failed writing the configuration " f"'wifi' key to {identifier}")

            if wifi_device:
                ip = self.current_device_identifier()[1]
                output = self.adb.command("connect {}".format(ip))
                self.is_connection_success_handler(output, ip=ip)
            else:
                self.adb.command("reconnect offline")
            # As we have attempted to connect; refresh the panel
            self.refresh_devices()
        else:
            output = self.adb.command("connect {}".format(device_id))
            self.is_connection_success_handler(output, ip=device_id)

    def tcpip_paired_device(self):
        if self.devices_view.currentItem():
            _, identifier = self.current_device_identifier()
        else:
            identifier = ""
        __exit_code = self.adb.tcpip(identifier=identifier)
        if __exit_code != 0:
            self.display_public_message(
                "TCP/IP failed on device. " "Please reconnect USB and try again"
            )
        else:
            self.display_public_message("TCP/IP completed successfully.")
            time.sleep(0.1)  # wait for everything to get settled
            if identifier.count(".") >= 3:
                self.ping_paired_device(device_id=identifier)
            else:
                self.ping_paired_device()

    def current_device_identifier(self, need_status=False):
        if self.devices_view.currentItem():
            if need_status:
                return (
                    self.devices_view.currentItem().text().split()[0],
                    self.devices_view.currentItem().text().split()[1],
                    self.devices_view.currentItem().text().split()[2],
                )
            else:
                return (
                    self.devices_view.currentItem().text().split()[0],
                    self.devices_view.currentItem().text().split()[1],
                )
        else:
            raise ValueError("No item is selected in QListView")

    def scan_config_devices_update_list_view(self):
        """
        Scans for saved devices
        :return:
        """
        self.devices_view.clear()
        paired_devices = self.config["device"]
        for i in paired_devices:
            if paired_devices[i].get("wifi"):
                icon = ":/icons/icons/portrait_mobile_disconnect.svg"
                devices_view_list_item = QListWidgetItem(
                    QIcon(icon),
                    "{device}\n{mode}\n{status}".format(
                        device=paired_devices[i].get("model"),
                        mode=i,
                        status="Disconnected",
                    ),
                )
                __sha_shift = self.config.get("sha_shift", 5)
                __sha = hashlib.sha256(str(i).encode()).hexdigest()[
                    __sha_shift : __sha_shift + 6
                ]
                devices_view_list_item.setToolTip(
                    "<span style='color: #{color}'>Device</snap>: <b>{d}</b>\n"
                    "Status: {s}".format(
                        d=i,
                        s="Disconnected. Right click 'ping' to attempt " "reconnect",
                        color=__sha,
                    )
                )
                devices_view_list_item.setFont(QFont("Noto Sans", 8))
                self.devices_view.addItem(devices_view_list_item)
        return paired_devices

    def scan_devices_update_list_view(self):
        """
        Scan for new devices; and update the list view
        :return:
        """
        # self.devices_view.clear()
        device_exists_in_view = False
        paired_devices = []
        for index in range(self.devices_view.count()):
            paired_devices.append(self.devices_view.item(index))

        __devices = self.adb.devices_detailed()
        log(__devices)
        for i in __devices:
            device_is_wifi = i["identifier"].count(".") >= 3 and (
                ":" in i["identifier"]
            )

            if i["identifier"] not in self.config["device"].keys():
                device_paired_and_exists = False
                self.config["device"][i["identifier"]] = {"rotation": 0}
            else:
                device_paired_and_exists = True

            if device_is_wifi:
                _icon_suffix = "_wifi"
            else:
                _icon_suffix = "_usb"

            icon = ":/icons/icons/portrait_mobile_white{}.svg".format(_icon_suffix)

            if i["status"] == "offline":
                icon = ":/icons/icons/portrait_mobile_error.svg"
            elif i["status"] == "unauthorized":
                icon = ":/icons/icons/portrait_mobile_warning.svg"

            if i["status"] == "no_permission":
                log("pairfilter: 5")
                # https://stackoverflow.com/questions/
                # 53887322/adb-devices-no-permissions-user-in-
                # plugdev-group-are-your-udev-rules-wrong
                udev_error = (
                    "Error connecting to device. Your udev rules are"
                    " incorrect. See https://stackoverflow.com/questions"
                    "/53887322/adb-devices-no-permissions-user-in-plugdev-"
                    "group-are-your-udev-rules-wrong"
                )
                self.display_public_message(udev_error)
                print(udev_error)
                return []
            # Check if device is unauthorized
            elif i["status"] == "unauthorized":
                log("unauthorized device detected: Click Allow on your device")
                log("pairfilter: 4")
                # The device is connected; and might/might't paired in the past
                # And is connected to the same IP address
                # It is possibly a bug with the connection;
                # Temporarily create a new QListItem to display the
                # device with the error
                paired = False
                device_paired_and_exists = False
                self.display_public_message(
                    f"{i['identifier']} is unauthorized. Please click allow "
                    f"on your device."
                )
                # Remove other devices with the same id and offline and
                # unauthorized
                self.remove_device_device_view(
                    i["identifier"], statuses=["offline", "unauthorized"]
                )
                # Unauthorized device cannot be considered as a paired device
                devices_view_list_item = QListWidgetItem()
            else:
                # check if device is paired
                # if yes, just update the list item
                if not device_paired_and_exists:
                    paired = False
                    devices_view_list_item = QListWidgetItem()
                else:
                    for paired_device in paired_devices:
                        if paired_device.text().split()[0] == i["model"]:
                            log("pairfilter: 1")
                            paired = True
                            devices_view_list_item = paired_device
                            # as we have found a paired device
                            # we know by assumption; there cannot be two
                            # devices with the same local IP address;
                            # lets scan the devices_view once more in a loop
                            # to check for any device with the same
                            # identifier and remove them; based on this same
                            # assumption
                            self.remove_device_device_view(
                                i["identifier"], statuses=["offline", "unauthorized"]
                            )
                            break
                        elif paired_device.text().split()[1] == i["identifier"]:
                            log("pairfilter: 2")
                            self.remove_device_device_view(
                                i["identifier"], statuses=["offline", "unauthorized"]
                            )
                            devices_view_list_item = QListWidgetItem()
                            paired = False
                            break
                    else:
                        log("pairfilter: 3")
                        paired = False
                        devices_view_list_item = QListWidgetItem()

            devices_view_list_item.setIcon(QIcon(icon))

            devices_view_list_item.setText(
                "{device}\n{mode}\n{status}".format(
                    device=i["model"], mode=i["identifier"], status=i["status"]
                )
            )
            __sha_shift = self.config.get("sha_shift", 5)
            __sha = hashlib.sha256(str(i["identifier"]).encode()).hexdigest()[
                __sha_shift : __sha_shift + 6
            ]
            devices_view_list_item.setToolTip(
                "Device: "
                "<span style='color: #{inv_color};background-color: #{color}'>"
                "<b>{d}</b></span>\n"
                "<br>"
                "Model: {m}\n<br>"
                "Alias: {a}\n<br>"
                "Status: {s}\n<br>"
                "Transport ID: {t}\n<br>"
                "Paired: {p}".format(
                    d=i["identifier"],
                    m=i["model"],
                    a=i["product"],
                    s=i["status"],
                    t=i["transport_id"],
                    p=paired,
                    color=__sha,
                    inv_color=str(hex(0xFFFFFF - int(__sha, 16))[2:]),
                )
            )

            devices_view_list_item.setFont(QFont("Noto Sans", 8))
            log(f"Pairing status: {device_paired_and_exists}")
            if device_paired_and_exists and device_is_wifi:
                # we need to only neglect wifi devices
                # paired usb device need to still show in the display
                continue
            elif device_exists_in_view:
                # devices exists in the list with the same status and
                # we should not add the new detected list item
                continue
            # If and only if the device doesn't exist; add it
            self.devices_view.addItem(devices_view_list_item)
        return __devices

    def remove_device_device_view(self, identifier: str = "", statuses=()):
        """
        Removes all QListWidgetItems from the device_view for all matching
        identifier
        :param identifier: str
        :param statuses: Iterable
        :return:
        """
        for index in range(self.devices_view.count() - 1, -1, -1):
            for status in statuses:
                if self.devices_view.item(index):
                    if (
                        str(identifier) in self.devices_view.item(index).text()
                        and str(status) in self.devices_view.item(index).text()
                    ):
                        self.devices_view.takeItem(index)
        return

    def __dimension_change_cb(self):
        if self.dimensionDefaultCheckbox.isChecked():
            self.dimensionSlider.setEnabled(False)
            self.config["dimension"] = None
            self.dimensionText.setInputMask("")
            self.dimensionText.setText("DEFAULT")
        else:
            self.dimensionSlider.setEnabled(True)
            self.config["dimension"] = int(self.dimensionSlider.value())
            self.dimensionText.setText(" " + str(self.config["dimension"]) + "px")
            self.dimensionSlider.sliderMoved.connect(self.__slider_change_cb)
            self.dimensionSlider.sliderReleased.connect(self.__slider_change_cb)

    def __slider_change_cb(self):
        self.config["dimension"] = int(self.dimensionSlider.value())
        self.dimensionText.setText(str(self.config["dimension"]) + "px")

    def __dial_change_cb(self):
        self.config["bitrate"] = int(self.dial.value())
        self.bitrateText.setText(str(self.config["bitrate"]) + "KB/s")

    def progress(self, val):
        self.progressBar.setValue(val)
        if (val + 4) >= 100:
            return 100
        else:
            return val + 100 / 20

    @staticmethod
    def is_device_unusable(status):
        if any(("unauth" in status, "offline" in status)):
            return True
        else:
            return False

    def show_device_status_failure(self, status):
        self.display_public_message(
            f"Device is {status}. Please reconnect / press allow."
        )

    def __reset_message_box_stylesheet(self):
        stylesheet = (
            "background-color: qlineargradient("
            "spread:pad, x1:0, y1:0, x2:1, y2:1, "
            "stop:0 rgba(0, 255, 255, 255), "
            "stop:1 rgba(0, 255, 152, 255)); "
            "border-radius: 10px;"
        )
        self.private_message_box_adb.setStyleSheet(stylesheet)

    def __select_first_device(self):
        self.devices_view.setCurrentIndex(
            QModelIndex(self.devices_view.model().index(0, 0))
        )

    def display_public_message(self, message):
        """
        sets the message box information (GUI) with the string message
        :param message: str
        :return: None
        """
        self.private_message_box_adb.setText(message)

    def check_devices_status_and_select_first_if_only_one(self, values_devices_list):
        """
        Checks the devices in the Grid View, and then checks if any device
        is available or offline accordingly display the error message. If
        only one device was detected, automatically select the first device
        and check its status of connectivity. Return the selected device if
        multiple devices were detected by adb. Return device_id, status and
        a bool more_devices if more than one device was found
        :param values_devices_list:
        :type values_devices_list:
        :return:
        :rtype:
        """
        if len(values_devices_list) == 0:
            # Could not detect any device
            self.display_public_message("Could not find any devices")
            return 0
        elif self.devices_view.currentIndex() is None and len(values_devices_list) != 1:
            # No device is selected and more than one device found
            self.display_public_message("Please select a device below.")
            return 0
        else:
            # Device selected
            log("DEVICE LIST", len(values_devices_list), values_devices_list)
            if len(values_devices_list) == 1:
                # found only one device
                # ======================================================
                # Store the current rotation temporarily
                __selected_rotation = self.device_rotation.currentIndex()
                self.__select_first_device()
                # Restore the selected rotation
                self.device_rotation.setCurrentIndex(__selected_rotation)
                # =======================================================
                # get the status and identifier of the device;
                # return if device is not in a connectable state
                try:
                    _, device_id, _stat = self.current_device_identifier(
                        need_status=True
                    )
                    if self.is_device_unusable(_stat):
                        self.show_device_status_failure(_stat)
                        return 0
                except ValueError:
                    self.display_public_message(
                        "Please select a device from the list view"
                    )
                    return 0
                more_devices = False
            elif self.devices_view.currentItem() is None:
                # no item is selected
                self.display_public_message("Please select a device below.")
                return 0
            else:
                _, device_id, _stat = self.current_device_identifier(need_status=True)
                if self.is_device_unusable(_stat):
                    self.show_device_status_failure(_stat)
                    return 0
                log("Device_id = {}".format(device_id))
                more_devices = True
        return device_id, more_devices, _stat

    def start_act(self):
        """
        Main brain of guiscrcpy; handles what to do when
        :return:
        """
        # prepare launch of scrcpy,
        # reset colors
        # reset vars

        # 1: reset
        self.options = ""
        progress = self.progress(0)
        self.__reset_message_box_stylesheet()

        # ====================================================================
        # 2: Update UI to start checking
        self.display_public_message("CHECKING DEVICE CONNECTION")
        initial_time = time.time()
        progress = self.progress(progress)

        # ====================================================================
        # 3: Check devices
        values_devices_list = self.scan_devices_update_list_view()
        _e = self.check_devices_status_and_select_first_if_only_one(values_devices_list)
        if _e is None or isinstance(_e, int):
            return _e
        device_id, more_devices, _stat = _e
        progress = self.progress(progress)

        # ====================================================================
        # 4: Parse dimension slider
        # check if the defaultDimension is checked or not for giving signal
        if self.dimensionDefaultCheckbox.isChecked():
            self.dimensionSlider.setEnabled(False)
            self.dimensionText.setText("DEFAULT")
            self.config["dimension"] = None
        else:
            self.dimensionSlider.setEnabled(True)
            self.config["dimension"] = int(self.dimensionSlider.value())
            self.dimensionSlider.setValue(self.config["dimension"])
            self.dimensionText.setText(str(self.config["dimension"]) + "px")
        # edit configuration files to update dimension key
        if self.config["dimension"] is None:
            self.options = " "
        elif self.config["dimension"] is not None:
            self.options = " -m " + str(self.config["dimension"])
        else:
            self.options = ""
        progress = self.progress(progress)

        # ====================================================================
        # 5: Check if always_on and fullscreen switches are on
        if self.aotop.isChecked():
            self.options += " --always-on-top"
        if self.fullscreen.isChecked():
            self.options += " -f"
            self.config["fullscreen"] = True
        else:
            self.config["fullscreen"] = False
        progress = self.progress(progress)

        # ====================================================================
        # 6: Check if show touches / recording are on
        if self.showTouches.isChecked():
            self.options += " --show-touches"
            self.config["swtouches"] = True
        else:
            self.config["swtouches"] = False
        progress = self.progress(progress)

        # ====================================================================
        # 7: Check if the record option is selected
        if self.recScui.isChecked():
            self.options += " -r " + str(int(time.time())) + ".mp4 "
        progress = self.progress(progress)

        # ====================================================================
        # 8: Check if the display is forced to be on
        if self.displayForceOn.isChecked():
            self.options += " -S"
            self.config["dispRO"] = True
        else:
            self.config["dispRO"] = False
        progress = self.progress(progress)

        # ====================================================================
        # 9: Parse bitrate
        # Bitrate is parsed, by editing the bitrate mask
        if self.bitrateText.text().split()[1][0] in ["K", "M", "T"]:
            bitrate_multiplier = str(self.bitrateText.text().split()[1][0])
        elif self.bitrateText.text().split()[1][0] == "B":
            bitrate_multiplier = "B"
        else:
            # do not proceed. Invalid file size multiplier
            multiplier_error = (
                f"Invalid file size multiplier \
            '{str(self.bitrateText.text().split()[1][0])}'. "
                f"Please use only K, M, T only"
            )
            print(multiplier_error)
            self.display_public_message(multiplier_error)
            return False
        if self.bitrateText.text().split()[0].isdigit():
            bitrate_integer = int(self.bitrateText.text().split()[0])
        else:
            bitrate_integer = 8000
        self.options += " -b {}{}".format(bitrate_integer, bitrate_multiplier)
        self.config["bitrate"] = bitrate_integer
        progress = self.progress(progress)

        # ====================================================================
        # 10: Make user aware that there were no problems in connection
        # or in the data provided by the user
        log("CONNECTION ESTABLISHED")
        self.progressBar.setValue(50)
        log("Flags passed to scrcpy engine : " + self.options)
        self.progressBar.setValue(60)
        self.config["extra"] = self.flaglineedit.text()
        progress = self.progress(progress)

        # ====================================================================
        # 11: Initialize User Experience Mapper
        ux = UXMapper(
            adb=self.adb, device_id=device_id, sha_shift=self.config.get("sha_shift", 5)
        )
        progress = self.progress(progress)
        always_on_top = (
            self.config.get("panels_always_on_top", False)
            or not self.panels_not_always_on_top
        )
        # ====================================================================
        # 12: Init side_panel if necessary
        if self.check_side_panel.isChecked():
            self.config["panels"]["toolkit"] = True
            side_instance = InterfaceToolkit(
                parent=self,
                ux_mapper=ux,
                frame=self.force_window_frame,
                always_on_top=always_on_top,
            )
            for instance in self.child_windows:
                if (
                    instance.ux.get_sha() == side_instance.ux.get_sha()
                    and instance.name == side_instance.name
                    and not instance.isHidden()
                ):
                    break
            else:
                side_instance.init()
                self.child_windows.append(side_instance)
        else:
            self.config["panels"]["toolkit"] = False
        progress = self.progress(progress)

        # ====================================================================
        # 13: Init bottom_panel if necessary
        if self.check_bottom_panel.isChecked():
            self.config["panels"]["bottom"] = True
            panel_instance = Panel(
                parent=self,
                ux_mapper=ux,
                frame=self.force_window_frame,
                always_on_top=always_on_top,
            )
            for instance in self.child_windows:
                if (
                    instance.ux.get_sha() == panel_instance.ux.get_sha()
                    and instance.name == panel_instance.name
                    and not instance.isHidden()
                ):
                    break
            else:
                panel_instance.init()
                self.child_windows.append(panel_instance)
        else:
            self.config["panels"]["bottom"] = False
        progress = self.progress(progress)

        # ====================================================================
        # 14: Init swipe panel if necessary
        if self.check_swipe_panel.isChecked():
            self.config["panels"]["swipe"] = True
            swipe_instance = SwipeUX(
                ux_wrapper=ux,
                frame=self.force_window_frame,
                always_on_top=always_on_top,
            )  # Load swipe UI
            for instance in self.child_windows:
                if (
                    instance.ux.get_sha() == swipe_instance.ux.get_sha()
                    and instance.name == swipe_instance.name
                    and not instance.isHidden()
                ):
                    break
            else:
                swipe_instance.init()
                self.child_windows.append(swipe_instance)
        else:
            self.config["panels"]["swipe"] = False
        progress = self.progress(progress)

        # ====================================================================
        # 15: Generate uuid for device and set uuid color for PMBA
        hexdigest = ux.get_sha()[:6]
        stylesheet = f"background-color: #{hexdigest}; border-radius: 10px; "
        self.private_message_box_adb.setStyleSheet(stylesheet)
        progress = self.progress(progress)

        # ====================================================================
        # 16: Update device specific configuration
        model, identifier = self.current_device_identifier()
        # ====================================================================
        # 17: Parse rotation (scrcpy v1.13+)
        rotation_index = self.device_rotation.currentIndex() - 1
        if self.lock_rotation.isChecked():
            rotation_parameter = "--lock-video-orientation"
        else:
            rotation_parameter = "--rotation"
        if rotation_index != -1:
            self.options += " {} {}".format(rotation_parameter, rotation_index)
            self.config["device"][identifier]["rotation"] = rotation_index + 1
        else:
            self.config["device"][identifier]["rotation"] = 0

        # ====================================================================
        # 18: Update device specific configuration
        if identifier.count(".") >= 3 and identifier[-1].isdigit():
            self.config["device"][identifier]["wifi"] = True
            self.config["device"][identifier]["model"] = model

        # ====================================================================
        # 16: Parse scrcpy arguments
        if self.cmx is not None:
            self.config["cmx"] = " ".join(map(str, self.cmx))

        arguments_scrcpy = "{} {} {}".format(
            self.options, self.config["extra"], self.config["cmx"]
        )
        progress = self.progress(progress)

        # ====================================================================
        # 18: Handle more devices
        if more_devices:
            # guiscrcpy found more devices
            # scrcpy will fail if more than one device is found
            # its important to pass the device serial id, if more than one
            # device is found
            arguments_scrcpy = f"-s {device_id} {arguments_scrcpy}"

        # tell end users that the color of the device is this
        self.display_public_message(
            f"Device {device_id} is connected; (color id matches " f"toolkit color)"
        )
        log("Device connection completed successfully.")
        log("Private message box updated successfully")
        progress = self.progress(progress)

        # ====================================================================
        # 19: spawn scrcpy
        if not self.debug__no_scrcpy:
            # for debugging purposes, its important to not start scrcpy
            # every time
            self.scrcpy.start(arguments_scrcpy, stdout=sys.stdout, stderr=sys.stderr)
        progress = self.progress(progress)

        # ====================================================================
        # 20: Calculate time
        final_time = time.time()
        eta = final_time - initial_time
        print("scrcpy launched in {:.2f}s".format(eta))
        progress = self.progress(progress)

        # ====================================================================
        # 22: Update configuration
        self.config_manager.update_config(self.config)
        self.config_manager.write_file()
        progress = self.progress(progress)

        return self.progress(progress)


def set_scrcpy_server_path(config):
    scrcpy_server_path_env = os.getenv("SCRCPY_SERVER_PATH", None)
    if scrcpy_server_path_env:
        if not os.path.exists(scrcpy_server_path_env):
            server_path = open_exe_name_dialog(None, "scrcpy-server")
            if server_path is None:
                raise ScrcpyServerNotFoundError("User did not select scrcpy server")
            config["scrcpy-server"] = server_path
            os.environ["SCRCPY_SERVER_PATH"] = server_path
    elif (
        (scrcpy_server_path_env is None)
        and (
            (
                isinstance(config.get("scrcpy-server"), str)
                and not os.path.exists(config.get("scrcpy-server"))
            )
            or config.get("scrcpy-server") is None
        )
    ) and (platform.System().system() == "Windows"):
        server_path = open_exe_name_dialog(None, "scrcpy-server")
        if server_path is None:
            raise ScrcpyServerNotFoundError("User did not select scrcpy server")
        config["scrcpy-server"] = server_path
        os.environ["SCRCPY_SERVER_PATH"] = server_path
    elif platform.System().system() == "Windows":
        os.environ["SCRCPY_SERVER_PATH"] = config["scrcpy-server"]
    return config


def bootstrap(
    app: QtWidgets.QApplication,
    config_manager: InterfaceConfig,
    theme: str = "Breeze",
    aot: bool = True,
    debug_no_scrcpy: bool = False,
    hide_wm_frame: bool = True,
):
    """
    Launch the guiscrcpy window
    :return:
    """
    config = config_manager.get_config()

    # load fonts
    font_database = QFontDatabase()
    for font in FONTS:
        s = font_database.addApplicationFont(":/font/fonts/{ttf}".format(ttf=font))
        if s == -1:  # loading the font failed
            # https://doc.qt.io/qt-5/qfontdatabase.html
            print(fc("{y}Failed to load {ttf} font.{rst}", ttf=font))

    # set theme
    app.setStyle(theme)
    # apply stylesheet
    if theme == "Breeze":
        # The Qdarkstylesheet is based on Breeze, lets load them on default
        app.setStyleSheet(dark_stylesheet())

    # load splash
    splash_pix = QPixmap(":/res/ui/guiscrcpy-branding.png")
    splash = QtWidgets.QSplashScreen(splash_pix)
    splash.setMask(splash_pix.mask())
    splash.show()
    app.processEvents()

    # on windows, users are likely not to add the scrcpy-server to the
    # SCRCPY_SERVER_PATH
    config_manager.update_config(set_scrcpy_server_path(config))
    config_manager.write_file()
    adb = AndroidDebugBridge(config_manager.get_config().get("adb"))
    scrcpy = ScrcpyBridge(config_manager.get_config().get("scrcpy"))
    config_manager["adb"] = adb.get_path()
    config_manager["scrcpy"] = scrcpy.get_path()
    guiscrcpy = InterfaceGuiscrcpy(
        config_manager=config_manager,
        adb=adb,
        scrcpy=scrcpy,
        force_window_frame=not hide_wm_frame,
        panels_not_always_on_top=not aot,
        debug_no_scrcpy=debug_no_scrcpy,
    )
    guiscrcpy.show()
    app.processEvents()
    splash.hide()
    app.exec_()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'guiscrcpy/ui/settings.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(441, 447)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.layoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.layoutWidget.setGeometry(QtCore.QRect(0, 10, 441, 408))
        self.layoutWidget.setObjectName("layoutWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.layoutWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.b1c2 = QtWidgets.QLineEdit(self.layoutWidget)
        self.b1c2.setObjectName("b1c2")
        self.gridLayout.addWidget(self.b1c2, 10, 4, 1, 2)
        self.label_6 = QtWidgets.QLabel(self.layoutWidget)
        self.label_6.setAlignment(QtCore.Qt.AlignCenter)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 11, 3, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.layoutWidget)
        self.label_5.setAlignment(QtCore.Qt.AlignCenter)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 11, 1, 1, 1)
        self.a1 = QtWidgets.QCheckBox(self.layoutWidget)
        self.a1.setObjectName("a1")
        self.gridLayout.addWidget(self.a1, 0, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.layoutWidget)
        self.label_4.setMinimumSize(QtCore.QSize(25, 0))
        self.label_4.setAlignment(QtCore.Qt.AlignCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 10, 3, 1, 1)
        self.a4 = QtWidgets.QCheckBox(self.layoutWidget)
        self.a4.setObjectName("a4")
        self.gridLayout.addWidget(self.a4, 4, 0, 1, 1)
        self.a6d1 = QtWidgets.QToolButton(self.layoutWidget)
        self.a6d1.setObjectName("a6d1")
        self.gridLayout.addWidget(self.a6d1, 6, 1, 1, 1)
        self.b2c1 = QtWidgets.QLineEdit(self.layoutWidget)
        self.b2c1.setObjectName("b2c1")
        self.gridLayout.addWidget(self.b2c1, 11, 2, 1, 1)
        self.a3 = QtWidgets.QCheckBox(self.layoutWidget)
        self.a3.setObjectName("a3")
        self.gridLayout.addWidget(self.a3, 3, 0, 1, 1)
        self.a8c1 = QtWidgets.QLineEdit(self.layoutWidget)
        self.a8c1.setObjectName("a8c1")
        self.gridLayout.addWidget(self.a8c1, 7, 1, 1, 5)
        self.label = QtWidgets.QLabel(self.layoutWidget)
        self.label.setEnabled(False)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 1, 1, 1, 1)
        self.a9 = QtWidgets.QCheckBox(self.layoutWidget)
        self.a9.setObjectName("a9")
        self.gridLayout.addWidget(self.a9, 8, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.layoutWidget)
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 10, 1, 1, 1)
        self.updatebutton = QtWidgets.QPushButton(self.layoutWidget)
        self.updatebutton.setObjectName("updatebutton")
        self.gridLayout.addWidget(self.updatebutton, 12, 2, 1, 4)
        self.a6 = QtWidgets.QCheckBox(self.layoutWidget)
        self.a6.setObjectName("a6")
        self.gridLayout.addWidget(self.a6, 6, 0, 1, 1)
        self.a5c1 = QtWidgets.QLineEdit(self.layoutWidget)
        self.a5c1.setObjectName("a5c1")
        self.gridLayout.addWidget(self.a5c1, 5, 1, 1, 5)
        self.a8 = QtWidgets.QCheckBox(self.layoutWidget)
        self.a8.setObjectName("a8")
        self.gridLayout.addWidget(self.a8, 7, 0, 1, 1)
        self.b1c1 = QtWidgets.QLineEdit(self.layoutWidget)
        self.b1c1.setObjectName("b1c1")
        self.gridLayout.addWidget(self.b1c1, 10, 2, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.layoutWidget)
        self.label_2.setEnabled(False)
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 3, 1, 1)
        self.b1 = QtWidgets.QCheckBox(self.layoutWidget)
        self.b1.setObjectName("b1")
        self.gridLayout.addWidget(self.b1, 10, 0, 1, 1)
        self.a2c1 = QtWidgets.QLineEdit(self.layoutWidget)
        self.a2c1.setEnabled(False)
        self.a2c1.setObjectName("a2c1")
        self.gridLayout.addWidget(self.a2c1, 1, 2, 1, 1)
        self.b2c2 = QtWidgets.QLineEdit(self.layoutWidget)
        self.b2c2.setObjectName("b2c2")
        self.gridLayout.addWidget(self.b2c2, 11, 4, 1, 2)
        self.b2 = QtWidgets.QCheckBox(self.layoutWidget)
        self.b2.setObjectName("b2")
        self.gridLayout.addWidget(self.b2, 11, 0, 1, 1)
        self.a2 = QtWidgets.QCheckBox(self.layoutWidget)
        self.a2.setEnabled(False)
        self.a2.setObjectName("a2")
        self.gridLayout.addWidget(self.a2, 1, 0, 1, 1)
        self.b0 = QtWidgets.QCheckBox(self.layoutWidget)
        self.b0.setObjectName("b0")
        self.gridLayout.addWidget(self.b0, 9, 0, 1, 1)
        self.b0c1 = QtWidgets.QLineEdit(self.layoutWidget)
        self.b0c1.setObjectName("b0c1")
        self.gridLayout.addWidget(self.b0c1, 9, 1, 1, 5)
        self.a5 = QtWidgets.QCheckBox(self.layoutWidget)
        self.a5.setObjectName("a5")
        self.gridLayout.addWidget(self.a5, 5, 0, 1, 1)
        self.a6c1 = QtWidgets.QLineEdit(self.layoutWidget)
        self.a6c1.setObjectName("a6c1")
        self.gridLayout.addWidget(self.a6c1, 6, 2, 1, 4)
        self.a2c2 = QtWidgets.QLineEdit(self.layoutWidget)
        self.a2c2.setEnabled(False)
        self.a2c2.setObjectName("a2c2")
        self.gridLayout.addWidget(self.a2c2, 1, 4, 1, 2)
        self.a3e1 = QtWidgets.QSpinBox(self.layoutWidget)
        self.a3e1.setObjectName("a3e1")
        self.gridLayout.addWidget(self.a3e1, 3, 1, 1, 5)
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Settings"))
        self.label_6.setText(_translate("MainWindow", "h"))
        self.label_5.setText(_translate("MainWindow", "w"))
        self.a1.setText(_translate("MainWindow", "Always on Top"))
        self.label_4.setText(_translate("MainWindow", "y"))
        self.a4.setText(_translate("MainWindow", "Prefer Text"))
        self.a6d1.setText(_translate("MainWindow", "..."))
        self.a3.setText(_translate("MainWindow", "Max Frame / second (FPS)"))
        self.label.setText(_translate("MainWindow", "x"))
        self.a9.setText(_translate("MainWindow", "Borderless Window"))
        self.label_3.setText(_translate("MainWindow", "x"))
        self.updatebutton.setText(_translate("MainWindow", "Update"))
        self.a6.setText(_translate("MainWindow", "Record File"))
        self.a8.setText(_translate("MainWindow", "Serial"))
        self.label_2.setText(_translate("MainWindow", "y"))
        self.b1.setText(_translate("MainWindow", "Window position"))
        self.b2.setText(_translate("MainWindow", "Window size"))
        self.a2.setText(_translate("MainWindow", "Crop Width"))
        self.b0.setText(_translate("MainWindow", "Window Title"))
        self.a5.setText(_translate("MainWindow", "Push Target"))



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'mainwindow.ui'
##
## Created by: Qt User Interface Compiler version 5.15.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import (QCoreApplication, QDate, QDateTime, QMetaObject,
    QObject, QPoint, QRect, QSize, QTime, QUrl, Qt)
from PySide2.QtGui import (QBrush, QColor, QConicalGradient, QCursor, QFont,
    QFontDatabase, QIcon, QKeySequence, QLinearGradient, QPalette, QPainter,
    QPixmap, QRadialGradient)
from PySide2.QtGui import QGradient
from PySide2.QtWidgets import *

from  . import rsrc_rc

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(539, 629)
        sizePolicy = QSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QSize(500, 420))
        font = QFont()
        font.setFamily(u"Titillium Web")
        font.setPointSize(10)
        MainWindow.setFont(font)
        icon = QIcon()
        icon.addFile(u":/res/ui/guiscrcpy_logo.png", QSize(), QIcon.Normal, QIcon.Off)
        MainWindow.setWindowIcon(icon)
        MainWindow.setStyleSheet(u"QPushButton {\n"
"border-radius: 10px;\n"
"	background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 152, 255));\n"
"color: rgb(0, 0, 0);\n"
"}\n"
"QPushButton:pressed {\n"
"border-radius: 10px;\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 152, 255));\n"
"color: rgb(0, 0, 0);\n"
"}\n"
".QPushButton:hover {\n"
"border-radius: 10px;\n"
"	background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 199, 199, 255), stop:1 rgba(0, 190, 113, 255));\n"
"color: rgb(0, 0, 0);\n"
" }\n"
".QPushButton#quit{\n"
"                        background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(255, 0, 0, 255), stop:1 rgba(255, 155, 0, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#quit:hover{             \n"
"	background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(172, 0, 0,"
                        " 255), stop:1 rgba(175, 106, 0, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#usbaud{\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 0, 255, 255), stop:0.901961 rgba(152, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#usbaud:hover{                        \n"
"	background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(172, 0, 0, 255), stop:1 rgba(175, 106, 0, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#mapnow{\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(253, 0, 255, 255), stop:0.990196 rgba(88, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#initmapnow{\n"
"background-color: qlineargradient(spread:pad, x1:1, y1:1, x2:0, y2:0, stop:0.0196078 rgba(0, 141, 255, 255), stop:1 rgba(52, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
"."
                        "QPushButton#initmapnow:hover{\n"
"background-color:qlineargradient(spread:pad, x1:1, y1:1, x2:0, y2:0, stop:0.0196078 rgba(0, 72, 131, 255), stop:1 rgba(24, 0, 122, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#mapnow:hover{\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(199, 0, 255, 255), stop:0.990196 rgba(88, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#network_button{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;	\n"
" }\n"
".QPushButton#settings_button{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;	\n"
" }\n"
".QPushButton#refreshdevices{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;	\n"
" }\n"
".QPushButton#restart_adb_server{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;	\n"
" }\n"
"\n"
"\n"
"\n"
"")
        MainWindow.setUnifiedTitleAndToolBarOnMac(False)
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.centralwidget.setEnabled(True)
        sizePolicy1 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
        sizePolicy1.setHorizontalStretch(24)
        sizePolicy1.setVerticalStretch(25)
        sizePolicy1.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy1)
        self.centralwidget.setMinimumSize(QSize(500, 300))
        self.centralwidget.setStyleSheet(u"")
        self.gridLayout_5 = QGridLayout(self.centralwidget)
        self.gridLayout_5.setObjectName(u"gridLayout_5")
        self.frame = QFrame(self.centralwidget)
        self.frame.setObjectName(u"frame")
        sizePolicy2 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(0)
        sizePolicy2.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy2)
        self.verticalLayout = QVBoxLayout(self.frame)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setSizeConstraint(QLayout.SetMaximumSize)
        self.verticalLayout.setContentsMargins(7, 1, 7, -1)
        self.gridLayout_4 = QGridLayout()
        self.gridLayout_4.setObjectName(u"gridLayout_4")
        self.gridLayout_4.setSizeConstraint(QLayout.SetMinimumSize)
        self.gridLayout_4.setVerticalSpacing(1)
        self.fullscreen = QCheckBox(self.frame)
        self.fullscreen.setObjectName(u"fullscreen")
        sizePolicy2.setHeightForWidth(self.fullscreen.sizePolicy().hasHeightForWidth())
        self.fullscreen.setSizePolicy(sizePolicy2)
        self.fullscreen.setMinimumSize(QSize(10, 20))
        font1 = QFont()
        font1.setFamily(u"Noto Sans")
        font1.setPointSize(10)
        self.fullscreen.setFont(font1)
        icon1 = QIcon()
        icon1.addFile(u":/icons/icons/increase-size-option.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.fullscreen.setIcon(icon1)

        self.gridLayout_4.addWidget(self.fullscreen, 0, 4, 1, 1)

        self.aotop = QCheckBox(self.frame)
        self.aotop.setObjectName(u"aotop")
        sizePolicy2.setHeightForWidth(self.aotop.sizePolicy().hasHeightForWidth())
        self.aotop.setSizePolicy(sizePolicy2)
        self.aotop.setMinimumSize(QSize(10, 20))
        self.aotop.setFont(font1)
        self.aotop.setToolTipDuration(2)
        icon2 = QIcon()
        icon2.addFile(u":/icons/icons/fire-symbol.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.aotop.setIcon(icon2)

        self.gridLayout_4.addWidget(self.aotop, 1, 5, 1, 1)

        self.refreshdevices = QPushButton(self.frame)
        self.refreshdevices.setObjectName(u"refreshdevices")
        sizePolicy2.setHeightForWidth(self.refreshdevices.sizePolicy().hasHeightForWidth())
        self.refreshdevices.setSizePolicy(sizePolicy2)
        self.refreshdevices.setMinimumSize(QSize(22, 22))
        self.refreshdevices.setMaximumSize(QSize(30, 16777215))
        icon3 = QIcon()
        icon3.addFile(u":/icons/icons/refresh-page-option.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.refreshdevices.setIcon(icon3)
        self.refreshdevices.setIconSize(QSize(15, 15))

        self.gridLayout_4.addWidget(self.refreshdevices, 7, 2, 1, 1)

        self.check_swipe_panel = QCheckBox(self.frame)
        self.check_swipe_panel.setObjectName(u"check_swipe_panel")
        self.check_swipe_panel.setFont(font1)
        icon4 = QIcon()
        icon4.addFile(u":/icons/icons/guiscrcpy_swipe_panel.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.check_swipe_panel.setIcon(icon4)

        self.gridLayout_4.addWidget(self.check_swipe_panel, 2, 0, 1, 4)

        self.showTouches = QCheckBox(self.frame)
        self.showTouches.setObjectName(u"showTouches")
        sizePolicy2.setHeightForWidth(self.showTouches.sizePolicy().hasHeightForWidth())
        self.showTouches.setSizePolicy(sizePolicy2)
        self.showTouches.setMinimumSize(QSize(10, 20))
        self.showTouches.setFont(font1)
        icon5 = QIcon()
        icon5.addFile(u":/icons/icons/hand-finger-pointing-down.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.showTouches.setIcon(icon5)

        self.gridLayout_4.addWidget(self.showTouches, 2, 4, 1, 1)

        self.recScui = QCheckBox(self.frame)
        self.recScui.setObjectName(u"recScui")
        self.recScui.setEnabled(True)
        sizePolicy2.setHeightForWidth(self.recScui.sizePolicy().hasHeightForWidth())
        self.recScui.setSizePolicy(sizePolicy2)
        self.recScui.setMinimumSize(QSize(10, 20))
        font2 = QFont()
        font2.setFamily(u"Noto Sans")
        font2.setPointSize(10)
        font2.setBold(False)
        font2.setItalic(False)
        font2.setWeight(50)
        self.recScui.setFont(font2)
        self.recScui.setToolTipDuration(2)
        icon6 = QIcon()
        icon6.addFile(u":/icons/icons/facetime-button.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.recScui.setIcon(icon6)

        self.gridLayout_4.addWidget(self.recScui, 0, 5, 1, 1)

        self.displayForceOn = QCheckBox(self.frame)
        self.displayForceOn.setObjectName(u"displayForceOn")
        sizePolicy2.setHeightForWidth(self.displayForceOn.sizePolicy().hasHeightForWidth())
        self.displayForceOn.setSizePolicy(sizePolicy2)
        self.displayForceOn.setMinimumSize(QSize(10, 20))
        self.displayForceOn.setFont(font1)
        self.displayForceOn.setToolTipDuration(2)
        icon7 = QIcon()
        icon7.addFile(u":/icons/icons/bullseye.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.displayForceOn.setIcon(icon7)

        self.gridLayout_4.addWidget(self.displayForceOn, 1, 4, 1, 1)

        self.lock_rotation = QCheckBox(self.frame)
        self.lock_rotation.setObjectName(u"lock_rotation")
        self.lock_rotation.setFont(font1)
        icon8 = QIcon()
        icon8.addFile(u":/icons/icons/padlock.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.lock_rotation.setIcon(icon8)

        self.gridLayout_4.addWidget(self.lock_rotation, 2, 5, 1, 1)

        self.check_bottom_panel = QCheckBox(self.frame)
        self.check_bottom_panel.setObjectName(u"check_bottom_panel")
        self.check_bottom_panel.setFont(font1)
        icon9 = QIcon()
        icon9.addFile(u":/icons/icons/guiscrcpy_bottom_panel.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.check_bottom_panel.setIcon(icon9)

        self.gridLayout_4.addWidget(self.check_bottom_panel, 0, 0, 1, 4)

        self.network_button = QPushButton(self.frame)
        self.network_button.setObjectName(u"network_button")
        sizePolicy3 = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Expanding)
        sizePolicy3.setHorizontalStretch(0)
        sizePolicy3.setVerticalStretch(0)
        sizePolicy3.setHeightForWidth(self.network_button.sizePolicy().hasHeightForWidth())
        self.network_button.setSizePolicy(sizePolicy3)
        self.network_button.setToolTipDuration(2)
        icon10 = QIcon()
        icon10.addFile(u":/icons/icons/wifi.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.network_button.setIcon(icon10)

        self.gridLayout_4.addWidget(self.network_button, 7, 0, 1, 1)

        self.check_side_panel = QCheckBox(self.frame)
        self.check_side_panel.setObjectName(u"check_side_panel")
        self.check_side_panel.setFont(font1)
        icon11 = QIcon()
        icon11.addFile(u":/icons/icons/guiscrcpy_side_panel.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.check_side_panel.setIcon(icon11)

        self.gridLayout_4.addWidget(self.check_side_panel, 1, 0, 1, 4)

        self.settings_button = QPushButton(self.frame)
        self.settings_button.setObjectName(u"settings_button")
        sizePolicy3.setHeightForWidth(self.settings_button.sizePolicy().hasHeightForWidth())
        self.settings_button.setSizePolicy(sizePolicy3)
        icon12 = QIcon()
        icon12.addFile(u":/icons/icons/gear.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.settings_button.setIcon(icon12)

        self.gridLayout_4.addWidget(self.settings_button, 7, 1, 1, 1)

        self.device_rotation = QComboBox(self.frame)
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.device_rotation.setObjectName(u"device_rotation")
        font3 = QFont()
        font3.setFamily(u"Noto Sans")
        font3.setPointSize(11)
        self.device_rotation.setFont(font3)

        self.gridLayout_4.addWidget(self.device_rotation, 7, 5, 1, 1)

        self.restart_adb_server = QPushButton(self.frame)
        self.restart_adb_server.setObjectName(u"restart_adb_server")
        sizePolicy2.setHeightForWidth(self.restart_adb_server.sizePolicy().hasHeightForWidth())
        self.restart_adb_server.setSizePolicy(sizePolicy2)
        self.restart_adb_server.setMinimumSize(QSize(22, 22))
        self.restart_adb_server.setMaximumSize(QSize(30, 16777215))
        self.restart_adb_server.setToolTipDuration(2)
        self.restart_adb_server.setIcon(icon7)
        self.restart_adb_server.setIconSize(QSize(15, 15))

        self.gridLayout_4.addWidget(self.restart_adb_server, 7, 3, 1, 1)


        self.verticalLayout.addLayout(self.gridLayout_4)

        self.devices_view = QListWidget(self.frame)
        icon13 = QIcon()
        icon13.addFile(u":/icons/icons/android.svg", QSize(), QIcon.Normal, QIcon.Off)
        __qlistwidgetitem = QListWidgetItem(self.devices_view)
        __qlistwidgetitem.setTextAlignment(Qt.AlignCenter);
        __qlistwidgetitem.setIcon(icon13);
        self.devices_view.setObjectName(u"devices_view")
        sizePolicy2.setHeightForWidth(self.devices_view.sizePolicy().hasHeightForWidth())
        self.devices_view.setSizePolicy(sizePolicy2)
        self.devices_view.setMaximumSize(QSize(16777215, 90))
        font4 = QFont()
        font4.setFamily(u"Noto Sans")
        font4.setPointSize(9)
        self.devices_view.setFont(font4)
        self.devices_view.setAutoFillBackground(True)
        self.devices_view.setStyleSheet(u"alternate-background-color: rgb(35, 35, 35);")
        self.devices_view.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
        self.devices_view.setSizeAdjustPolicy(QAbstractScrollArea.AdjustToContents)
        self.devices_view.setAutoScrollMargin(9)
        self.devices_view.setAlternatingRowColors(True)
        self.devices_view.setIconSize(QSize(35, 35))
        self.devices_view.setTextElideMode(Qt.ElideMiddle)
        self.devices_view.setProperty("isWrapping", False)
        self.devices_view.setResizeMode(QListView.Adjust)
        self.devices_view.setViewMode(QListView.IconMode)
        self.devices_view.setUniformItemSizes(True)
        self.devices_view.setBatchSize(100)
        self.devices_view.setItemAlignment(Qt.AlignCenter)
        self.devices_view.setSortingEnabled(True)

        self.verticalLayout.addWidget(self.devices_view)

        self.private_message_box_adb = QPushButton(self.frame)
        self.private_message_box_adb.setObjectName(u"private_message_box_adb")
        sizePolicy2.setHeightForWidth(self.private_message_box_adb.sizePolicy().hasHeightForWidth())
        self.private_message_box_adb.setSizePolicy(sizePolicy2)
        self.private_message_box_adb.setFont(font3)

        self.verticalLayout.addWidget(self.private_message_box_adb)

        self.gridLayout_3 = QGridLayout()
        self.gridLayout_3.setSpacing(0)
        self.gridLayout_3.setObjectName(u"gridLayout_3")
        self.dimensionDefaultCheckbox = QCheckBox(self.frame)
        self.dimensionDefaultCheckbox.setObjectName(u"dimensionDefaultCheckbox")
        sizePolicy2.setHeightForWidth(self.dimensionDefaultCheckbox.sizePolicy().hasHeightForWidth())
        self.dimensionDefaultCheckbox.setSizePolicy(sizePolicy2)
        font5 = QFont()
        font5.setFamily(u"Noto Sans")
        font5.setPointSize(11)
        font5.setBold(False)
        font5.setItalic(False)
        font5.setWeight(50)
        self.dimensionDefaultCheckbox.setFont(font5)
        self.dimensionDefaultCheckbox.setChecked(True)

        self.gridLayout_3.addWidget(self.dimensionDefaultCheckbox, 0, 3, 1, 2)

        self.label = QLabel(self.frame)
        self.label.setObjectName(u"label")
        sizePolicy2.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy2)
        self.label.setFont(font3)

        self.gridLayout_3.addWidget(self.label, 0, 1, 1, 1)

        self.bitrateText = QLineEdit(self.frame)
        self.bitrateText.setObjectName(u"bitrateText")
        sizePolicy2.setHeightForWidth(self.bitrateText.sizePolicy().hasHeightForWidth())
        self.bitrateText.setSizePolicy(sizePolicy2)
        font6 = QFont()
        font6.setFamily(u"Titillium Web")
        font6.setPointSize(26)
        font6.setBold(True)
        font6.setWeight(75)
        self.bitrateText.setFont(font6)
        self.bitrateText.setStyleSheet(u"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 0, 255));")
        self.bitrateText.setAlignment(Qt.AlignCenter)

        self.gridLayout_3.addWidget(self.bitrateText, 2, 1, 1, 1)

        self.dial = QDial(self.frame)
        self.dial.setObjectName(u"dial")
        sizePolicy4 = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
        sizePolicy4.setHorizontalStretch(0)
        sizePolicy4.setVerticalStretch(0)
        sizePolicy4.setHeightForWidth(self.dial.sizePolicy().hasHeightForWidth())
        self.dial.setSizePolicy(sizePolicy4)
        self.dial.setFont(font3)
        self.dial.setCursor(QCursor(Qt.SizeHorCursor))
        self.dial.setToolTipDuration(2)
        self.dial.setStyleSheet(u"background-color: rgb(0, 255, 255);\n"
"color: rgb(255, 0, 127);\n"
"gridline-color: rgb(255, 0, 0);\n"
"selection-background-color: rgb(12, 255, 0);\n"
"\n"
"image: url(:/res/ui/guiscrcpy_logo.png);")
        self.dial.setMinimum(64)
        self.dial.setMaximum(16000)
        self.dial.setSingleStep(2)
        self.dial.setValue(8000)
        self.dial.setOrientation(Qt.Horizontal)
        self.dial.setInvertedAppearance(False)
        self.dial.setInvertedControls(False)
        self.dial.setWrapping(False)
        self.dial.setNotchTarget(20.000000000000000)
        self.dial.setNotchesVisible(True)

        self.gridLayout_3.addWidget(self.dial, 0, 0, 4, 1)

        self.label_2 = QLabel(self.frame)
        self.label_2.setObjectName(u"label_2")

        self.gridLayout_3.addWidget(self.label_2, 0, 5, 1, 1)

        self.dimensionSlider = QSlider(self.frame)
        self.dimensionSlider.setObjectName(u"dimensionSlider")
        self.dimensionSlider.setEnabled(False)
        sizePolicy2.setHeightForWidth(self.dimensionSlider.sizePolicy().hasHeightForWidth())
        self.dimensionSlider.setSizePolicy(sizePolicy2)
        self.dimensionSlider.setStyleSheet(u"color: rgb(255, 255, 255);")
        self.dimensionSlider.setMinimum(320)
        self.dimensionSlider.setMaximum(2048)
        self.dimensionSlider.setValue(1280)
        self.dimensionSlider.setOrientation(Qt.Horizontal)

        self.gridLayout_3.addWidget(self.dimensionSlider, 3, 2, 1, 4)

        self.dimensionText = QLineEdit(self.frame)
        self.dimensionText.setObjectName(u"dimensionText")
        sizePolicy2.setHeightForWidth(self.dimensionText.sizePolicy().hasHeightForWidth())
        self.dimensionText.setSizePolicy(sizePolicy2)
        self.dimensionText.setFont(font6)
        self.dimensionText.setStyleSheet(u"color: rgb(255, 255, 255);\n"
"background-color: rgb(17, 17, 17);\n"
"border-radius: 10px;\n"
"")
        self.dimensionText.setMaxLength(32767)
        self.dimensionText.setAlignment(Qt.AlignCenter)

        self.gridLayout_3.addWidget(self.dimensionText, 2, 3, 1, 3)


        self.verticalLayout.addLayout(self.gridLayout_3)

        self.flaglineedit = QLineEdit(self.frame)
        self.flaglineedit.setObjectName(u"flaglineedit")
        sizePolicy5 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Maximum)
        sizePolicy5.setHorizontalStretch(0)
        sizePolicy5.setVerticalStretch(0)
        sizePolicy5.setHeightForWidth(self.flaglineedit.sizePolicy().hasHeightForWidth())
        self.flaglineedit.setSizePolicy(sizePolicy5)
        font7 = QFont()
        font7.setFamily(u"Monospace")
        self.flaglineedit.setFont(font7)

        self.verticalLayout.addWidget(self.flaglineedit)

        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setSpacing(5)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.quit = QPushButton(self.frame)
        self.quit.setObjectName(u"quit")
        sizePolicy6 = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Maximum)
        sizePolicy6.setHorizontalStretch(0)
        sizePolicy6.setVerticalStretch(0)
        sizePolicy6.setHeightForWidth(self.quit.sizePolicy().hasHeightForWidth())
        self.quit.setSizePolicy(sizePolicy6)
        self.quit.setMinimumSize(QSize(45, 45))
        self.quit.setToolTipDuration(2)
        self.quit.setStyleSheet(u"")
        icon14 = QIcon()
        icon14.addFile(u":/icons/icons/cross-mark-on-a-black-circle-background.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.quit.setIcon(icon14)

        self.horizontalLayout.addWidget(self.quit)

        self.pushButton = QPushButton(self.frame)
        self.pushButton.setObjectName(u"pushButton")
        sizePolicy7 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Maximum)
        sizePolicy7.setHorizontalStretch(0)
        sizePolicy7.setVerticalStretch(0)
        sizePolicy7.setHeightForWidth(self.pushButton.sizePolicy().hasHeightForWidth())
        self.pushButton.setSizePolicy(sizePolicy7)
        self.pushButton.setMinimumSize(QSize(45, 45))
        font8 = QFont()
        font8.setFamily(u"Titillium Web")
        font8.setPointSize(11)
        font8.setBold(True)
        font8.setWeight(75)
        self.pushButton.setFont(font8)
        self.pushButton.setToolTipDuration(2)

        self.horizontalLayout.addWidget(self.pushButton)

        self.abtgit = QPushButton(self.frame)
        self.abtgit.setObjectName(u"abtgit")
        sizePolicy8 = QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum)
        sizePolicy8.setHorizontalStretch(0)
        sizePolicy8.setVerticalStretch(0)
        sizePolicy8.setHeightForWidth(self.abtgit.sizePolicy().hasHeightForWidth())
        self.abtgit.setSizePolicy(sizePolicy8)
        self.abtgit.setMinimumSize(QSize(45, 45))
        icon15 = QIcon()
        icon15.addFile(u":/icons/icons/github.logo.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.abtgit.setIcon(icon15)
        self.abtgit.setIconSize(QSize(20, 20))

        self.horizontalLayout.addWidget(self.abtgit)

        self.usbaud = QPushButton(self.frame)
        self.usbaud.setObjectName(u"usbaud")
        sizePolicy9 = QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum)
        sizePolicy9.setHorizontalStretch(11)
        sizePolicy9.setVerticalStretch(0)
        sizePolicy9.setHeightForWidth(self.usbaud.sizePolicy().hasHeightForWidth())
        self.usbaud.setSizePolicy(sizePolicy9)
        self.usbaud.setMinimumSize(QSize(45, 45))
        icon16 = QIcon()
        icon16.addFile(u":/icons/icons/volume-up-interface-symbol.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.usbaud.setIcon(icon16)

        self.horizontalLayout.addWidget(self.usbaud)

        self.initmapnow = QPushButton(self.frame)
        self.initmapnow.setObjectName(u"initmapnow")
        sizePolicy9.setHeightForWidth(self.initmapnow.sizePolicy().hasHeightForWidth())
        self.initmapnow.setSizePolicy(sizePolicy9)
        self.initmapnow.setMinimumSize(QSize(45, 45))
        self.initmapnow.setToolTipDuration(3)
        icon17 = QIcon()
        icon17.addFile(u":/icons/icons/mapper_init.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.initmapnow.setIcon(icon17)
        self.initmapnow.setIconSize(QSize(40, 40))

        self.horizontalLayout.addWidget(self.initmapnow)

        self.executeaction = QPushButton(self.frame)
        self.executeaction.setObjectName(u"executeaction")
        sizePolicy5.setHeightForWidth(self.executeaction.sizePolicy().hasHeightForWidth())
        self.executeaction.setSizePolicy(sizePolicy5)
        self.executeaction.setMinimumSize(QSize(45, 45))
        font9 = QFont()
        font9.setFamily(u"Titillium Web")
        font9.setPointSize(11)
        font9.setBold(True)
        font9.setItalic(False)
        font9.setWeight(75)
        self.executeaction.setFont(font9)
        self.executeaction.setStyleSheet(u"")
        icon18 = QIcon()
        icon18.addFile(u":/icons/icons/small-rocket-ship-silhouette.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.executeaction.setIcon(icon18)
        self.executeaction.setIconSize(QSize(20, 16))

        self.horizontalLayout.addWidget(self.executeaction)


        self.verticalLayout.addLayout(self.horizontalLayout)

        self.progressBar = QProgressBar(self.frame)
        self.progressBar.setObjectName(u"progressBar")
        palette = QPalette()
        brush = QBrush(QColor(255, 255, 255, 255))
        brush.setStyle(Qt.SolidPattern)
        palette.setBrush(QPalette.Active, QPalette.WindowText, brush)
        gradient = QLinearGradient(0, 0, 1, 0)
        gradient.setSpread(QGradient.PadSpread)
        gradient.setCoordinateMode(QGradient.ObjectBoundingMode)
        gradient.setColorAt(0, QColor(0, 255, 255, 255))
        gradient.setColorAt(1, QColor(0, 255, 0, 255))
        brush1 = QBrush(gradient)
        palette.setBrush(QPalette.Active, QPalette.Button, brush1)
        palette.setBrush(QPalette.Active, QPalette.Text, brush)
        palette.setBrush(QPalette.Active, QPalette.ButtonText, brush)
        gradient1 = QLinearGradient(0, 0, 1, 0)
        gradient1.setSpread(QGradient.PadSpread)
        gradient1.setCoordinateMode(QGradient.ObjectBoundingMode)
        gradient1.setColorAt(0, QColor(0, 255, 255, 255))
        gradient1.setColorAt(1, QColor(0, 255, 0, 255))
        brush2 = QBrush(gradient1)
        palette.setBrush(QPalette.Active, QPalette.Base, brush2)
        gradient2 = QLinearGradient(0, 0, 1, 0)
        gradient2.setSpread(QGradient.PadSpread)
        gradient2.setCoordinateMode(QGradient.ObjectBoundingMode)
        gradient2.setColorAt(0, QColor(0, 255, 255, 255))
        gradient2.setColorAt(1, QColor(0, 255, 0, 255))
        brush3 = QBrush(gradient2)
        palette.setBrush(QPalette.Active, QPalette.Window, brush3)
        brush4 = QBrush(QColor(85, 255, 0, 255))
        brush4.setStyle(Qt.SolidPattern)
        palette.setBrush(QPalette.Active, QPalette.Highlight, brush4)
        palette.setBrush(QPalette.Active, QPalette.HighlightedText, brush)
        brush5 = QBrush(QColor(255, 255, 255, 128))
        brush5.setStyle(Qt.NoBrush)
#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
        palette.setBrush(QPalette.Active, QPalette.PlaceholderText, brush5)
#endif
        palette.setBrush(QPalette.Inactive, QPalette.WindowText, brush)
        gradient3 = QLinearGradient(0, 0, 1, 0)
        gradient3.setSpread(QGradient.PadSpread)
        gradient3.setCoordinateMode(QGradient.ObjectBoundingMode)
        gradient3.setColorAt(0, QColor(0, 255, 255, 255))
        gradient3.setColorAt(1, QColor(0, 255, 0, 255))
        brush6 = QBrush(gradient3)
        palette.setBrush(QPalette.Inactive, QPalette.Button, brush6)
        palette.setBrush(QPalette.Inactive, QPalette.Text, brush)
        palette.setBrush(QPalette.Inactive, QPalette.ButtonText, brush)
        gradient4 = QLinearGradient(0, 0, 1, 0)
        gradient4.setSpread(QGradient.PadSpread)
        gradient4.setCoordinateMode(QGradient.ObjectBoundingMode)
        gradient4.setColorAt(0, QColor(0, 255, 255, 255))
        gradient4.setColorAt(1, QColor(0, 255, 0, 255))
        brush7 = QBrush(gradient4)
        palette.setBrush(QPalette.Inactive, QPalette.Base, brush7)
        gradient5 = QLinearGradient(0, 0, 1, 0)
        gradient5.setSpread(QGradient.PadSpread)
        gradient5.setCoordinateMode(QGradient.ObjectBoundingMode)
        gradient5.setColorAt(0, QColor(0, 255, 255, 255))
        gradient5.setColorAt(1, QColor(0, 255, 0, 255))
        brush8 = QBrush(gradient5)
        palette.setBrush(QPalette.Inactive, QPalette.Window, brush8)
        palette.setBrush(QPalette.Inactive, QPalette.Highlight, brush4)
        palette.setBrush(QPalette.Inactive, QPalette.HighlightedText, brush)
        brush9 = QBrush(QColor(255, 255, 255, 128))
        brush9.setStyle(Qt.NoBrush)
#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
        palette.setBrush(QPalette.Inactive, QPalette.PlaceholderText, brush9)
#endif
        palette.setBrush(QPalette.Disabled, QPalette.WindowText, brush)
        gradient6 = QLinearGradient(0, 0, 1, 0)
        gradient6.setSpread(QGradient.PadSpread)
        gradient6.setCoordinateMode(QGradient.ObjectBoundingMode)
        gradient6.setColorAt(0, QColor(0, 255, 255, 255))
        gradient6.setColorAt(1, QColor(0, 255, 0, 255))
        brush10 = QBrush(gradient6)
        palette.setBrush(QPalette.Disabled, QPalette.Button, brush10)
        palette.setBrush(QPalette.Disabled, QPalette.Text, brush)
        palette.setBrush(QPalette.Disabled, QPalette.ButtonText, brush)
        gradient7 = QLinearGradient(0, 0, 1, 0)
        gradient7.setSpread(QGradient.PadSpread)
        gradient7.setCoordinateMode(QGradient.ObjectBoundingMode)
        gradient7.setColorAt(0, QColor(0, 255, 255, 255))
        gradient7.setColorAt(1, QColor(0, 255, 0, 255))
        brush11 = QBrush(gradient7)
        palette.setBrush(QPalette.Disabled, QPalette.Base, brush11)
        gradient8 = QLinearGradient(0, 0, 1, 0)
        gradient8.setSpread(QGradient.PadSpread)
        gradient8.setCoordinateMode(QGradient.ObjectBoundingMode)
        gradient8.setColorAt(0, QColor(0, 255, 255, 255))
        gradient8.setColorAt(1, QColor(0, 255, 0, 255))
        brush12 = QBrush(gradient8)
        palette.setBrush(QPalette.Disabled, QPalette.Window, brush12)
        palette.setBrush(QPalette.Disabled, QPalette.Highlight, brush4)
        palette.setBrush(QPalette.Disabled, QPalette.HighlightedText, brush)
        brush13 = QBrush(QColor(255, 255, 255, 128))
        brush13.setStyle(Qt.NoBrush)
#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
        palette.setBrush(QPalette.Disabled, QPalette.PlaceholderText, brush13)
#endif
        self.progressBar.setPalette(palette)
        self.progressBar.setFont(font)
        self.progressBar.setStyleSheet(u"")
        self.progressBar.setValue(100)

        self.verticalLayout.addWidget(self.progressBar)


        self.gridLayout_5.addWidget(self.frame, 1, 0, 1, 1)

        self.frame1 = QFrame(self.centralwidget)
        self.frame1.setObjectName(u"frame1")
        self.horizontalLayout_2 = QHBoxLayout(self.frame1)
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalLayout_2.setSizeConstraint(QLayout.SetMaximumSize)
        self.label_4 = QLabel(self.frame1)
        self.label_4.setObjectName(u"label_4")
        sizePolicy10 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
        sizePolicy10.setHorizontalStretch(0)
        sizePolicy10.setVerticalStretch(0)
        sizePolicy10.setHeightForWidth(self.label_4.sizePolicy().hasHeightForWidth())
        self.label_4.setSizePolicy(sizePolicy10)
        self.label_4.setMinimumSize(QSize(60, 60))
        self.label_4.setMaximumSize(QSize(60, 60))
        self.label_4.setPixmap(QPixmap(u":/res/ui/guiscrcpy_logo.png"))
        self.label_4.setScaledContents(True)

        self.horizontalLayout_2.addWidget(self.label_4)

        self.verticalLayout_2 = QVBoxLayout()
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.verticalLayout_2.setSizeConstraint(QLayout.SetMaximumSize)
        self.label_3 = QLabel(self.frame1)
        self.label_3.setObjectName(u"label_3")
        sizePolicy8.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy8)
        font10 = QFont()
        font10.setFamily(u"Titillium Web")
        font10.setPointSize(28)
        font10.setBold(True)
        font10.setItalic(False)
        font10.setWeight(75)
        self.label_3.setFont(font10)
        self.label_3.setStyleSheet(u"")

        self.verticalLayout_2.addWidget(self.label_3)

        self.build_label = QLabel(self.frame1)
        self.build_label.setObjectName(u"build_label")
        sizePolicy5.setHeightForWidth(self.build_label.sizePolicy().hasHeightForWidth())
        self.build_label.setSizePolicy(sizePolicy5)
        font11 = QFont()
        font11.setFamily(u"Noto Sans")
        self.build_label.setFont(font11)
        self.build_label.setStyleSheet(u"color: rgb(255, 255, 255);")

        self.verticalLayout_2.addWidget(self.build_label)


        self.horizontalLayout_2.addLayout(self.verticalLayout_2)


        self.gridLayout_5.addWidget(self.frame1, 0, 0, 1, 1)

        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        self.statusbar.setFont(font)
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"guiscrcpy", None))
#if QT_CONFIG(statustip)
        MainWindow.setStatusTip(QCoreApplication.translate("MainWindow", u"GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                https://github.com/srevinsaju/guiscrcpy\n"
"            ", None))
#endif // QT_CONFIG(statustip)
        self.fullscreen.setText(QCoreApplication.translate("MainWindow", u"Fullscreen", None))
#if QT_CONFIG(tooltip)
        self.aotop.setToolTip(QCoreApplication.translate("MainWindow", u"Keep display always on top of other windows", None))
#endif // QT_CONFIG(tooltip)
        self.aotop.setText(QCoreApplication.translate("MainWindow", u"Always on Top", None))
        self.refreshdevices.setText("")
        self.check_swipe_panel.setText(QCoreApplication.translate("MainWindow", u"Swipe Panel", None))
        self.showTouches.setText(QCoreApplication.translate("MainWindow", u"Show touches", None))
#if QT_CONFIG(tooltip)
        self.recScui.setToolTip(QCoreApplication.translate("MainWindow", u"<html><head/><body><p>Record your screen mirroring to your home directory. In Linux, it is in ~guiscrcpy directory. In Windows, it is in C:\\Users\\&lt;username&gt;\\ with the UNIX date, followed by .mp4; For manual configuration and path selection, use the settings icon</p></body></html>", None))
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        self.recScui.setStatusTip(QCoreApplication.translate("MainWindow", u"See tooltip", None))
#endif // QT_CONFIG(statustip)
        self.recScui.setText(QCoreApplication.translate("MainWindow", u"Record screen", None))
#if QT_CONFIG(tooltip)
        self.displayForceOn.setToolTip(QCoreApplication.translate("MainWindow", u"Use your computer screen as your android device's HD Display", None))
#endif // QT_CONFIG(tooltip)
        self.displayForceOn.setText(QCoreApplication.translate("MainWindow", u"Keep display off ", None))
        self.lock_rotation.setText(QCoreApplication.translate("MainWindow", u"Lock Rotation", None))
        self.check_bottom_panel.setText(QCoreApplication.translate("MainWindow", u"Bottom Panel", None))
#if QT_CONFIG(tooltip)
        self.network_button.setToolTip(QCoreApplication.translate("MainWindow", u"Launch Network Manager", None))
#endif // QT_CONFIG(tooltip)
        self.network_button.setText("")
        self.check_side_panel.setText(QCoreApplication.translate("MainWindow", u"Side Panel", None))
        self.settings_button.setText("")
        self.device_rotation.setItemText(0, QCoreApplication.translate("MainWindow", u"Default Rotation", None))
        self.device_rotation.setItemText(1, QCoreApplication.translate("MainWindow", u"Potrait", None))
        self.device_rotation.setItemText(2, QCoreApplication.translate("MainWindow", u"Landscape", None))
        self.device_rotation.setItemText(3, QCoreApplication.translate("MainWindow", u"Potrait (flipped)", None))
        self.device_rotation.setItemText(4, QCoreApplication.translate("MainWindow", u"Landscape (flipped)", None))

#if QT_CONFIG(tooltip)
        self.restart_adb_server.setToolTip(QCoreApplication.translate("MainWindow", u"Restart the adb-server", None))
#endif // QT_CONFIG(tooltip)
        self.restart_adb_server.setText("")

        __sortingEnabled = self.devices_view.isSortingEnabled()
        self.devices_view.setSortingEnabled(False)
        ___qlistwidgetitem = self.devices_view.item(0)
        ___qlistwidgetitem.setText(QCoreApplication.translate("MainWindow", u"Nothing here", None));
        self.devices_view.setSortingEnabled(__sortingEnabled)

        self.private_message_box_adb.setText("")
        self.dimensionDefaultCheckbox.setText(QCoreApplication.translate("MainWindow", u"Keep Default Dimensions", None))
        self.label.setText(QCoreApplication.translate("MainWindow", u"Bitrate", None))
        self.bitrateText.setInputMask(QCoreApplication.translate("MainWindow", u"00000 A\\B/s", None))
        self.bitrateText.setText(QCoreApplication.translate("MainWindow", u"8000 KB/s", None))
#if QT_CONFIG(tooltip)
        self.dial.setToolTip(QCoreApplication.translate("MainWindow", u"Changing the bitrate of the screen mirrorring. Useful to show playback at normal speed without lags", None))
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        self.dial.setStatusTip(QCoreApplication.translate("MainWindow", u"Adjust Bitrate. Leave it untouched for defualts", None))
#endif // QT_CONFIG(statustip)
        self.label_2.setText("")
        self.dimensionText.setInputMask("")
        self.dimensionText.setText(QCoreApplication.translate("MainWindow", u"DEFAULT", None))
        self.flaglineedit.setPlaceholderText(QCoreApplication.translate("MainWindow", u"Enter additional flags to pass to scrcpy", None))
#if QT_CONFIG(statustip)
        self.quit.setStatusTip(QCoreApplication.translate("MainWindow", u"Quit GUI and end all subprocess windows ", None))
#endif // QT_CONFIG(statustip)
        self.quit.setText("")
#if QT_CONFIG(statustip)
        self.pushButton.setStatusTip(QCoreApplication.translate("MainWindow", u"Reset guiscrcpy configuration files", None))
#endif // QT_CONFIG(statustip)
        self.pushButton.setText(QCoreApplication.translate("MainWindow", u"  RESET  ", None))
#if QT_CONFIG(statustip)
        self.abtgit.setStatusTip(QCoreApplication.translate("MainWindow", u"Check me out on Github", None))
#endif // QT_CONFIG(statustip)
        self.abtgit.setText("")
#if QT_CONFIG(statustip)
        self.usbaud.setStatusTip(QCoreApplication.translate("MainWindow", u"Start @rom1v's usbaudio. Needs usbaudio to be on PATH", None))
#endif // QT_CONFIG(statustip)
        self.usbaud.setText("")
#if QT_CONFIG(tooltip)
        self.initmapnow.setToolTip(QCoreApplication.translate("MainWindow", u"Initialize mapper", None))
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        self.initmapnow.setStatusTip(QCoreApplication.translate("MainWindow", u"Initialize mapper", None))
#endif // QT_CONFIG(statustip)
        self.initmapnow.setText("")
#if QT_CONFIG(statustip)
        self.executeaction.setStatusTip(QCoreApplication.translate("MainWindow", u"Start Scrcpy Executable right now. Please check if Scrcpy is added to path", None))
#endif // QT_CONFIG(statustip)
        self.executeaction.setText(QCoreApplication.translate("MainWindow", u"START SCRCPY", None))
#if QT_CONFIG(statustip)
        self.progressBar.setStatusTip(QCoreApplication.translate("MainWindow", u"Progress Bar", None))
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        self.label_4.setToolTip(QCoreApplication.translate("MainWindow", u"GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                        https://github.com/srevinsaju/guiscrcpy\n"
"                    ", None))
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        self.label_4.setStatusTip(QCoreApplication.translate("MainWindow", u"GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                        https://github.com/srevinsaju/guiscrcpy\n"
"                    ", None))
#endif // QT_CONFIG(statustip)
        self.label_4.setText("")
#if QT_CONFIG(statustip)
        self.label_3.setStatusTip(QCoreApplication.translate("MainWindow", u"GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                        https://github.com/srevinsaju/guiscrcpy\n"
"                    ", None))
#endif // QT_CONFIG(statustip)
        self.label_3.setText(QCoreApplication.translate("MainWindow", u"guiscrcpy                          ", None))
        self.build_label.setText(QCoreApplication.translate("MainWindow", u"Build", None))
    # retranslateUi




"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import logging
import os

from guiscrcpy.platform.windows_tools.tools import make_shortcut


class Windows:
    def __init__(self):
        self.make_config()

    @staticmethod
    def make_config():
        path = os.path.expanduser(os.path.join("~", "AppData", "Local", "guiscrcpy"))
        if not os.path.exists(path):
            try:
                os.makedirs(path)
            except Exception as e:
                logging.error(
                    "Error creating configuration filename in dir {path}. "
                    "Error code:{e}".format(path=path, e=e)
                )
        return path

    @staticmethod
    def system():
        return "Windows"

    def cfgpath(self):
        return self.make_config()

    def increment(self):
        pass

    @staticmethod
    def paths():
        return ["bin"]

    @staticmethod
    def install_fonts():
        return True

    @staticmethod
    def create_desktop():
        try:
            make_shortcut()
        except Exception as e:
            # do not stop users from using guiscrcpy
            # in case this small exception happens
            print("Desktop shortcut generation failed: {}".format(e))



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'guiscrcpy/ui/bottompanelui.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_HorizontalPanel(object):
    def setupUi(self, HorizontalPanel):
        HorizontalPanel.setObjectName("HorizontalPanel")
        HorizontalPanel.resize(397, 24)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/res/ui/guiscrcpy_logo.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        HorizontalPanel.setWindowIcon(icon)
        HorizontalPanel.setStyleSheet("\n"
".QPushButton {\n"
"border-radius: 1px;\n"
"color: rgb(0, 0, 0);\n"
" \n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:0.915182, x2:0, y2:0.926, stop:0.897059 rgba(41, 41, 41, 255), stop:1 rgba(30, 30, 30, 255));\n"
"                    }\n"
"\n"
"QPushButton:pressed {\n"
"border-radius: 5px;\n"
"                      \n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 152, 255));\n"
"color: rgb(0, 0, 0);\n"
"                        }\n"
"QPushButton:hover {\n"
"border-radius: 5px;\n"
"                      \n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 199, 199, 255), stop:1 rgba(0, 190, 113, 255));\n"
"color: rgb(0, 0, 0);\n"
"                        }\n"
"")
        self.backk = QtWidgets.QPushButton(HorizontalPanel)
        self.backk.setEnabled(True)
        self.backk.setGeometry(QtCore.QRect(230, 0, 51, 25))
        self.backk.setStyleSheet("")
        self.backk.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/icons/chevron-sign-left.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.backk.setIcon(icon1)
        self.backk.setObjectName("backk")
        self.powerUII = QtWidgets.QPushButton(HorizontalPanel)
        self.powerUII.setEnabled(True)
        self.powerUII.setGeometry(QtCore.QRect(20, 0, 81, 25))
        self.powerUII.setStyleSheet("")
        self.powerUII.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/icons/power.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.powerUII.setIcon(icon2)
        self.powerUII.setCheckable(False)
        self.powerUII.setObjectName("powerUII")
        self.menuUII = QtWidgets.QPushButton(HorizontalPanel)
        self.menuUII.setEnabled(True)
        self.menuUII.setGeometry(QtCore.QRect(110, 0, 51, 25))
        self.menuUII.setStyleSheet("")
        self.menuUII.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/icons/reorder-option.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.menuUII.setIcon(icon3)
        self.menuUII.setObjectName("menuUII")
        self.vdownn = QtWidgets.QPushButton(HorizontalPanel)
        self.vdownn.setEnabled(True)
        self.vdownn.setGeometry(QtCore.QRect(290, 0, 31, 25))
        self.vdownn.setStyleSheet("")
        self.vdownn.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icons/icons/reduced-volume.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.vdownn.setIcon(icon4)
        self.vdownn.setObjectName("vdownn")
        self.homee = QtWidgets.QPushButton(HorizontalPanel)
        self.homee.setEnabled(True)
        self.homee.setGeometry(QtCore.QRect(160, 0, 71, 25))
        self.homee.setStyleSheet("")
        self.homee.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icons/icons/home.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.homee.setIcon(icon5)
        self.homee.setObjectName("homee")
        self.vupp = QtWidgets.QPushButton(HorizontalPanel)
        self.vupp.setEnabled(True)
        self.vupp.setGeometry(QtCore.QRect(320, 0, 31, 25))
        self.vupp.setStyleSheet("")
        self.vupp.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icons/icons/volume-up-interface-symbol.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.vupp.setIcon(icon6)
        self.vupp.setObjectName("vupp")
        self.label = QtWidgets.QLabel(HorizontalPanel)
        self.label.setGeometry(QtCore.QRect(0, -10, 20, 41))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setScaledContents(True)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.bp_close = QtWidgets.QPushButton(HorizontalPanel)
        self.bp_close.setEnabled(True)
        self.bp_close.setGeometry(QtCore.QRect(350, 0, 31, 25))
        self.bp_close.setStyleSheet("")
        self.bp_close.setText("")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icons/icons/cross-mark-on-a-black-circle-background.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bp_close.setIcon(icon7)
        self.bp_close.setObjectName("bp_close")
        self.bp_device_id = QtWidgets.QPushButton(HorizontalPanel)
        self.bp_device_id.setGeometry(QtCore.QRect(380, 0, 20, 31))
        self.bp_device_id.setStyleSheet("")
        self.bp_device_id.setText("")
        self.bp_device_id.setObjectName("bp_device_id")
        self.homee.raise_()
        self.backk.raise_()
        self.powerUII.raise_()
        self.menuUII.raise_()
        self.vdownn.raise_()
        self.vupp.raise_()
        self.label.raise_()
        self.bp_close.raise_()
        self.bp_device_id.raise_()

        self.retranslateUi(HorizontalPanel)
        QtCore.QMetaObject.connectSlotsByName(HorizontalPanel)

    def retranslateUi(self, HorizontalPanel):
        _translate = QtCore.QCoreApplication.translate
        HorizontalPanel.setWindowTitle(_translate("HorizontalPanel", "guiscrcpy"))
        self.backk.setToolTip(_translate("HorizontalPanel", "Back key"))
        self.powerUII.setToolTip(_translate("HorizontalPanel", "Power on/off"))
        self.menuUII.setToolTip(_translate("HorizontalPanel", "Menu key"))
        self.vdownn.setToolTip(_translate("HorizontalPanel", "Volume Up"))
        self.homee.setToolTip(_translate("HorizontalPanel", "Home key"))
        self.label.setText(_translate("HorizontalPanel", "::"))
from . import rsrc_rc



import shutil


from ...install.finder import open_exe_name_dialog


class Bridge:
    name = None

    def __init__(self, path=None):
        if path is not None:
            self.path = path
        elif shutil.which(self.name):
            self.path = shutil.which(self.name)
        else:
            self.path = open_exe_name_dialog(None, self.name)
        if self.path is None:
            raise FileNotFoundError(f"Could not find '{self.name}' on $PATH.")
        self.post_init()

    def post_init(self):
        pass

    def get_path(self):
        return self.path



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'network.ui'
##
## Created by: Qt User Interface Compiler version 5.15.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import (QCoreApplication, QDate, QDateTime, QMetaObject,
    QObject, QPoint, QRect, QSize, QTime, QUrl, Qt)
from PySide2.QtGui import (QBrush, QColor, QConicalGradient, QCursor, QFont,
    QFontDatabase, QIcon, QKeySequence, QLinearGradient, QPalette, QPainter,
    QPixmap, QRadialGradient)
from PySide2.QtWidgets import *


class Ui_NetworkUI(object):
    def setupUi(self, NetworkUI):
        if not NetworkUI.objectName():
            NetworkUI.setObjectName(u"NetworkUI")
        NetworkUI.setWindowModality(Qt.ApplicationModal)
        NetworkUI.resize(374, 414)
        self.centralwidget = QWidget(NetworkUI)
        self.centralwidget.setObjectName(u"centralwidget")
        self.layoutWidget = QWidget(self.centralwidget)
        self.layoutWidget.setObjectName(u"layoutWidget")
        self.layoutWidget.setGeometry(QRect(2, 5, 371, 381))
        self.verticalLayout = QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.label = QLabel(self.layoutWidget)
        self.label.setObjectName(u"label")

        self.verticalLayout.addWidget(self.label)

        self.gridLayout = QGridLayout()
        self.gridLayout.setObjectName(u"gridLayout")
        self.listView = QListWidget(self.layoutWidget)
        self.listView.setObjectName(u"listView")

        self.gridLayout.addWidget(self.listView, 0, 0, 1, 2)

        self.nm_refresh = QPushButton(self.layoutWidget)
        self.nm_refresh.setObjectName(u"nm_refresh")

        self.gridLayout.addWidget(self.nm_refresh, 5, 0, 1, 1)

        self.tcpip = QPushButton(self.layoutWidget)
        self.tcpip.setObjectName(u"tcpip")

        self.gridLayout.addWidget(self.tcpip, 4, 1, 1, 1)

        self.spinBox = QSpinBox(self.layoutWidget)
        self.spinBox.setObjectName(u"spinBox")
        font = QFont()
        font.setBold(True)
        font.setWeight(75)
        self.spinBox.setFont(font)
        self.spinBox.setToolTipDuration(2)
        self.spinBox.setMinimum(1000)
        self.spinBox.setMaximum(99999)
        self.spinBox.setValue(5555)

        self.gridLayout.addWidget(self.spinBox, 4, 0, 1, 1)

        self.nm_connect = QPushButton(self.layoutWidget)
        self.nm_connect.setObjectName(u"nm_connect")

        self.gridLayout.addWidget(self.nm_connect, 5, 1, 1, 1)

        self.nm_det = QPushButton(self.layoutWidget)
        self.nm_det.setObjectName(u"nm_det")
        self.nm_det.setEnabled(False)

        self.gridLayout.addWidget(self.nm_det, 2, 0, 1, 2)

        self.lineEdit = QLineEdit(self.layoutWidget)
        self.lineEdit.setObjectName(u"lineEdit")

        self.gridLayout.addWidget(self.lineEdit, 1, 0, 1, 2)


        self.verticalLayout.addLayout(self.gridLayout)

        NetworkUI.setCentralWidget(self.centralwidget)
        self.statusbar = QStatusBar(NetworkUI)
        self.statusbar.setObjectName(u"statusbar")
        NetworkUI.setStatusBar(self.statusbar)

        self.retranslateUi(NetworkUI)

        QMetaObject.connectSlotsByName(NetworkUI)
    # setupUi

    def retranslateUi(self, NetworkUI):
        NetworkUI.setWindowTitle(QCoreApplication.translate("NetworkUI", u"Network Manager", None))
        self.label.setText(QCoreApplication.translate("NetworkUI", u"List of Network Devices", None))
#if QT_CONFIG(statustip)
        self.nm_refresh.setStatusTip(QCoreApplication.translate("NetworkUI", u"Refresh Devices list", None))
#endif // QT_CONFIG(statustip)
        self.nm_refresh.setText(QCoreApplication.translate("NetworkUI", u"REFRESH", None))
        self.tcpip.setText(QCoreApplication.translate("NetworkUI", u"TCPIP", None))
#if QT_CONFIG(tooltip)
        self.spinBox.setToolTip(QCoreApplication.translate("NetworkUI", u"Port number", None))
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        self.spinBox.setStatusTip(QCoreApplication.translate("NetworkUI", u"Port number", None))
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(statustip)
        self.nm_connect.setStatusTip(QCoreApplication.translate("NetworkUI", u"Establish connection", None))
#endif // QT_CONFIG(statustip)
        self.nm_connect.setText(QCoreApplication.translate("NetworkUI", u"CONNECT", None))
        self.nm_det.setText("")
        self.lineEdit.setPlaceholderText(QCoreApplication.translate("NetworkUI", u"Cannot find your IP address? Enter it manually here", None))
    # retranslateUi




"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

from guiscrcpy.theme.termcolor import ColorTerms


class Header:
    def __init__(self, commit):
        print(
            ColorTerms.UNDERLINE
            + "                                  "
            + ColorTerms.ENDC
        )
        print()
        print("guiscrcpy")
        print("by srevinsaju")
        print(ColorTerms.OKBLUE + commit + ColorTerms.ENDC)
        print(
            ColorTerms.OKBLUE + "Licensed under GNU GPL v3 (c) 2020  " + ColorTerms.ENDC
        )
        print(
            ColorTerms.UNDERLINE
            + "                                  "
            + ColorTerms.ENDC
        )
        print(ColorTerms.OKBLUE + "" + ColorTerms.ENDC)

        print()
        print(
            "MSG: Please ensure you have enabled",
            ColorTerms.OKGREEN + "USB Debugging" + ColorTerms.ENDC,
            "on your device. See README.md for more details",
        )



import logging
import sys
from subprocess import PIPE, TimeoutExpired, call

from .base import Bridge
from ..check import _get_dimension_raw_noexcept, get
from ..utils import decode_process, open_process, _


class AndroidDebugBridge(Bridge):
    name = "adb"

    def get_target_android_version(self, device_id=None):
        api = -1

        # This function uses device API level to identify different android versions instead of
        # Android version as they can break in scenarios where version names are like 8.1.0
        # Fixes: https://github.com/srevinsaju/guiscrcpy/issues/248
        _proc = self.shell("getprop ro.build.version.sdk", device_id=device_id)
        _ecode = _proc.wait()

        if _ecode == 0:
            api = int(_proc.stdout.read())
        else:
            raise RuntimeError("adb did not respond to getprop ro.build.version.sdk")

        return api

    def shell_input(self, command, device_id=None):
        path = self.path
        if device_id:
            open_process(
                _("{} -s {} shell input {}".format(path, device_id, command)),
                stdout=PIPE,
                stderr=PIPE,
            )
        else:
            open_process(
                _("{} shell input {}".format(path, command)),
                stdout=PIPE,
                stderr=PIPE,
            )

    def kill_adb_server(self):
        self.command(self.path, "kill-server")

    def get_dimensions(self, device_id=None):
        shell_adb = _get_dimension_raw_noexcept(path=self.path, device_id=device_id)
        try:
            if shell_adb.wait(timeout=3) != 0:
                print(
                    "E: Command 'adb shell wm size' exited with {}".format(
                        shell_adb.returncode
                    )
                )
                return False
        except TimeoutExpired:
            print("E: adb falied; timeout exceeded 10s, killing and " "respawining adb")
            self.kill_adb_server()
            if isinstance(device_id, str) and device_id.count(".") >= 3:
                self.command(self.path, "connect {}".format(device_id))
            shell_adb = _get_dimension_raw_noexcept(path=self.path, device_id=device_id)
            if shell_adb.wait(timeout=8) != 0:
                print(
                    "E: Command 'adb shell wm size' exited with {}".format(
                        shell_adb.returncode
                    )
                )
                return False
        raw_dimensions = shell_adb.stdout.read().decode().strip("\n")
        for i in ["Override size", "Physical size"]:
            if i in raw_dimensions:
                out = raw_dimensions[raw_dimensions.find(i) :]
                out_decoded = out.split(":")[1].strip()
                dimension_values = out_decoded.split("x")
                return dimension_values

        # As the for loop did not find any device; and hence we have reached
        # this line. Announce to the user regarding the same
        logging.error(
            "AndroidDeviceError: adb shell wm size did not return "
            "'Physical Size' or 'Override Size'"
        )
        return False

    def shell(self, command, device_id=None):
        if device_id:
            po = open_process(
                _("{} -s {} shell {}".format(self.path, device_id, command)),
                stdout=PIPE,
                stderr=PIPE,
            )
        else:
            po = open_process(
                _("{} shell {}".format(self.path, command)), stdout=PIPE, stderr=PIPE
            )
        return po

    def command(self, command, device_id=None):
        if device_id:
            adb_shell_output = open_process(
                _("{} -s {} {}".format(self.path, device_id, command)),
                stdout=PIPE,
                stderr=PIPE,
            )
        else:
            adb_shell_output = open_process(
                _("{} {}".format(self.path, command)), stdout=PIPE, stderr=PIPE
            )
        return adb_shell_output

    def tcpip(self, port=5555, identifier=""):
        if identifier:
            command = "{path} -s {identifier} -d tcpip {port}"
        else:
            command = "{path} -d tcpip {port}"
        exit_code = call(
            _(command.format(path=self.path, port=port, identifier=identifier)),
            stdout=sys.stdout,
            stderr=sys.stdout,
        )
        return exit_code

    def devices(self):
        proc = open_process(_(self.path + " devices"), stdout=PIPE)
        output = [[y.strip() for y in x.split("\t")] for x in decode_process(proc)[1:]][
            :-1
        ]

        logging.debug("ADB: {}".format(output))
        return output

    def devices_detailed(self):
        proc = open_process(_(self.path + " devices -l"), stdout=PIPE)
        output = [[y.strip() for y in x.split()] for x in decode_process(proc)[1:]][:-1]
        devices_found = []
        for device in output:
            # https://github.com/srevinsaju/guiscrcpy/issues/117
            if "udev" in device and "permission" in device:
                # This is an error with some linux and Windows OSes
                # This happens because the udev is not configured
                # and linux adb does not have access to reading the device
                # the status hence should be 'no_permission'
                status = "no_permission"
            else:
                status = device[1]
            description = {
                "identifier": device[0],
                "status": status,
                "product": get(device, 2, ":").split(":")[-1],
                "model": get(device, 3, ":").split(":")[-1],
                "device": get(device, 4, ":").split(":")[-1],
                "transport_id": get(device, 5, ":").split(":")[-1],
            }
            devices_found.append(description)
        logging.debug("ADB: {}".format(devices_found))
        return devices_found
